@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2015 Open Source Robotics Foundation
+ * Copyright (C) 2012-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -1416,9 +1416,6 @@ void ColladaLoader::LoadPolylist(TiXmlElement *_polylistXml,
   const unsigned int NORMAL = 1;
   const unsigned int TEXCOORD = 2;
   unsigned int otherSemantics = TEXCOORD + 1;
-  bool hasVertices = false;
-  bool hasNormals = false;
-  bool hasTexcoords = false;
 
   // look up table of position/normal/texcoord duplicate indices
   std::map<unsigned int, unsigned int> texDupMap;
@@ -1429,8 +1426,10 @@ void ColladaLoader::LoadPolylist(TiXmlElement *_polylistXml,
   if (_mesh->HasSkeleton())
     bindShapeMat = _mesh->GetSkeleton()->BindShapeTransform();
 
-  // read input elements
-  std::map<const unsigned int, int> inputs;
+  // read input elements. A vector of int is used because there can be
+  // multiple TEXCOORD inputs.
+  std::map<const unsigned int, std::set<int>> inputs;
+  unsigned int inputSize = 0;
   while (polylistInputXml)
   {
     std::string semantic = polylistInputXml->Attribute("semantic");
@@ -1443,25 +1442,22 @@ void ColladaLoader::LoadPolylist(TiXmlElement *_polylistXml,
           positionDupMap, normalDupMap);
       if (norms.size() > count)
         combinedVertNorms = true;
-      inputs[VERTEX] = ignition::math::parseInt(offset);
-      hasVertices = true;
+      inputs[VERTEX].insert(ignition::math::parseInt(offset));
     }
     else if (semantic == "NORMAL")
     {
       this->LoadNormals(source, _transform, norms, normalDupMap);
       combinedVertNorms = false;
-      inputs[NORMAL] = ignition::math::parseInt(offset);
-      hasNormals = true;
+      inputs[NORMAL].insert(ignition::math::parseInt(offset));
     }
     else if (semantic == "TEXCOORD")
     {
       this->LoadTexCoords(source, texcoords, texDupMap);
-      inputs[TEXCOORD] = ignition::math::parseInt(offset);
-      hasTexcoords = true;
+      inputs[TEXCOORD].insert(ignition::math::parseInt(offset));
     }
     else
     {
-      inputs[otherSemantics++] = ignition::math::parseInt(offset);
+      inputs[otherSemantics++].insert(ignition::math::parseInt(offset));
       gzwarn << "Polylist input semantic: '" << semantic << "' is currently"
           << " not supported" << std::endl;
     }
@@ -1469,6 +1465,9 @@ void ColladaLoader::LoadPolylist(TiXmlElement *_polylistXml,
     polylistInputXml = polylistInputXml->NextSiblingElement("input");
   }
 
+  for (const auto &input : inputs)
+    inputSize += input.second.size();
+
   // read vcount
   // break poly into triangles
   // if vcount >= 4, anchor around 0 (note this is bad for concave elements)
@@ -1488,15 +1487,17 @@ void ColladaLoader::LoadPolylist(TiXmlElement *_polylistXml,
   // vertexIndexMap is a map of collada vertex index to Gazebo submesh vertex
   // indices, used for identifying vertices that can be shared.
   std::map<unsigned int, std::vector<GeometryIndices> > vertexIndexMap;
-  unsigned int *values = new unsigned int[inputs.size()];
+  unsigned int *values = new unsigned int[inputSize];
+  memset(values, 0, inputSize);
 
   std::vector<std::string> strs;
   boost::split(strs, pStr, boost::is_any_of("   "));
-  std::vector<std::string>::iterator strs_iter = strs.begin();
+  std::vector<std::string>::iterator strsIter = strs.begin();
   for (unsigned int l = 0; l < vcounts.size(); ++l)
   {
     // put us at the beginning of the polygon list
-    if (l > 0) strs_iter += inputs.size()*vcounts[l-1];
+    if (l > 0)
+      strsIter += inputSize*vcounts[l-1];
 
     for (unsigned int k = 2; k < (unsigned int)vcounts[l]; ++k)
     {
@@ -1511,13 +1512,13 @@ void ColladaLoader::LoadPolylist(TiXmlElement *_polylistXml,
         if (j == 0)
           triangle_index = 0;
         if (j == 1)
-          triangle_index = (k-1)*inputs.size();
+          triangle_index = (k-1)*inputSize;
         if (j == 2)
-          triangle_index = (k)*inputs.size();
+          triangle_index = (k)*inputSize;
 
-        for (unsigned int i = 0; i < inputs.size(); ++i)
+        for (unsigned int i = 0; i < inputSize; ++i)
         {
-          values[i] = ignition::math::parseInt(strs_iter[triangle_index+i]);
+          values[i] = ignition::math::parseInt(strsIter[triangle_index+i]);
           /*gzerr << "debug parsing "
                 << " poly-i[" << l
                 << "] tri-end-index[" << k
@@ -1530,15 +1531,15 @@ void ColladaLoader::LoadPolylist(TiXmlElement *_polylistXml,
 
 
         unsigned int daeVertIndex = 0;
-        bool addIndex = !hasVertices;
+        bool addIndex = inputs[VERTEX].empty();
 
         // find a set of vertex/normal/texcoord that can be reused
         // only do this if the mesh has vertices
-        if (hasVertices)
+        if (!inputs[VERTEX].empty())
         {
           // Get the vertex position index value. If it is a duplicate then use
           // the existing index instead
-          daeVertIndex = values[inputs[VERTEX]];
+          daeVertIndex = values[*inputs[VERTEX].begin()];
           if (positionDupMap.find(daeVertIndex) != positionDupMap.end())
             daeVertIndex = positionDupMap[daeVertIndex];
 
@@ -1562,12 +1563,13 @@ void ColladaLoader::LoadPolylist(TiXmlElement *_polylistXml,
               bool normEqual = false;
               bool texEqual = false;
 
-              if (hasNormals)
+              if (!inputs[NORMAL].empty())
               {
                 // Get the vertex normal index value. If the normal is a
                 // duplicate then reset the index to the first instance of the
                 // duplicated position
-                unsigned int remappedNormalIndex = values[inputs[NORMAL]];
+                unsigned int remappedNormalIndex =
+                  values[*inputs[NORMAL].begin()];
                 if (normalDupMap.find(remappedNormalIndex)
                     != normalDupMap.end())
                  {
@@ -1577,22 +1579,29 @@ void ColladaLoader::LoadPolylist(TiXmlElement *_polylistXml,
                 if (iv.normalIndex == remappedNormalIndex)
                   normEqual = true;
               }
-              if (hasTexcoords)
+
+              if (!inputs[TEXCOORD].empty())
               {
+                // \todo: Add support for multiple texture maps to SubMesh.
+                // Here we are only using the first texture coordinates, when
+                // multiple could have been specified. See Gazebo issue #532.
+
                 // Get the vertex texcoord index value. If the texcoord is a
                 // duplicate then reset the index to the first instance of the
                 // duplicated texcoord
-                unsigned int remappedTexcoordIndex = values[inputs[TEXCOORD]];
+                unsigned int remappedTexcoordIndex =
+                  values[*inputs[TEXCOORD].begin()];
+
                 if (texDupMap.find(remappedTexcoordIndex) != texDupMap.end())
                   remappedTexcoordIndex = texDupMap[remappedTexcoordIndex];
 
-                if (iv.texcoordIndex == remappedTexcoordIndex)
-                  texEqual = true;
+                texEqual = iv.texcoordIndex == remappedTexcoordIndex;
               }
 
               // if the vertex has matching normal and texcoord index values
               // then the vertex can be reused.
-              if ((!hasNormals || normEqual) && (!hasTexcoords || texEqual))
+              if ((inputs[NORMAL].empty() || normEqual) &&
+                  (inputs[TEXCOORD].empty() || texEqual))
               {
                 // found a vertex that can be shared.
                 toDuplicate = false;
@@ -1609,7 +1618,7 @@ void ColladaLoader::LoadPolylist(TiXmlElement *_polylistXml,
         if (addIndex)
         {
           GeometryIndices input;
-          if (hasVertices)
+          if (!inputs[VERTEX].empty())
           {
             subMesh->AddVertex(verts[daeVertIndex]);
             unsigned int newVertIndex = subMesh->GetVertexCount()-1;
@@ -1635,18 +1644,25 @@ void ColladaLoader::LoadPolylist(TiXmlElement *_polylistXml,
             input.vertexIndex = daeVertIndex;
             input.mappedIndex = newVertIndex;
           }
-          if (hasNormals)
+          if (!inputs[NORMAL].empty())
           {
-            unsigned int inputRemappedNormalIndex = values[inputs[NORMAL]];
+            unsigned int inputRemappedNormalIndex =
+              values[*inputs[NORMAL].begin()];
             if (normalDupMap.find(inputRemappedNormalIndex)
                 != normalDupMap.end())
               inputRemappedNormalIndex = normalDupMap[inputRemappedNormalIndex];
             subMesh->AddNormal(norms[inputRemappedNormalIndex]);
             input.normalIndex = inputRemappedNormalIndex;
           }
-          if (hasTexcoords)
+
+          if (!inputs[TEXCOORD].empty())
           {
-            unsigned int inputRemappedTexcoordIndex = values[inputs[TEXCOORD]];
+            // \todo: Add support for multiple texture maps to SubMesh.
+            // Here we are only using the first texture coordinates, when
+            // multiple could have been specified.
+            unsigned int inputRemappedTexcoordIndex =
+              values[*inputs[TEXCOORD].begin()];
+
             if (texDupMap.find(inputRemappedTexcoordIndex) != texDupMap.end())
             {
               inputRemappedTexcoordIndex =
@@ -1658,7 +1674,7 @@ void ColladaLoader::LoadPolylist(TiXmlElement *_polylistXml,
           }
 
           // add the new gazebo submesh vertex index to the map
-          if (hasVertices)
+          if (!inputs[VERTEX].empty())
           {
             std::vector<GeometryIndices> inputValues;
             inputValues.push_back(input);
