@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2015 Open Source Robotics Foundation
+ * Copyright (C) 2012-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -78,7 +78,7 @@ TEST_F(Exception, GZASSERT_Enabled_ThrowAssertion)
 {
     ASSERT_DEATH(
       GZ_ASSERT(true == false, "Assert thrown"),
-      ".*Internal Program Error - assertion.*");
+      ".*Assertion.*failed.*|.*Internal Program Error - assertion.*");
 }
 #endif
 
