@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2015 Open Source Robotics Foundation
+ * Copyright (C) 2012-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,6 +14,7 @@
  * limitations under the License.
  *
  */
+
 #include <sys/stat.h>
 #include <string>
 #include <map>
@@ -30,6 +31,7 @@
 #include "gazebo/common/ColladaLoader.hh"
 #include "gazebo/common/ColladaExporter.hh"
 #include "gazebo/common/STLLoader.hh"
+#include "gazebo/common/OBJLoader.hh"
 #include "gazebo/gazebo_config.h"
 
 #ifdef HAVE_GTS
@@ -42,6 +44,10 @@
 using namespace gazebo;
 using namespace common;
 
+// added here for ABI compatibility
+// TODO move to header / private class when merging forward.
+static OBJLoader objLoader;
+
 //////////////////////////////////////////////////
 MeshManager::MeshManager()
 {
@@ -73,6 +79,7 @@ MeshManager::MeshManager()
 
   this->fileExtensions.push_back("stl");
   this->fileExtensions.push_back("dae");
+  this->fileExtensions.push_back("obj");
 }
 
 //////////////////////////////////////////////////
@@ -129,8 +136,13 @@ const Mesh *MeshManager::Load(const std::string &_filename)
       loader = this->stlLoader;
     else if (extension == "dae")
       loader = this->colladaLoader;
+    else if (extension == "obj")
+      loader = &objLoader;
     else
+    {
       gzerr << "Unsupported mesh format for file[" << _filename << "]\n";
+      return nullptr;
+    }
 
     try
     {
@@ -194,17 +206,6 @@ bool MeshManager::IsValidFilename(const std::string &_filename)
       extension) != this->fileExtensions.end();
 }
 
-//////////////////////////////////////////////////
-void MeshManager::GetMeshAABB(const Mesh *_mesh, math::Vector3 &_center,
-    math::Vector3 &_minXYZ, math::Vector3 &_maxXYZ)
-{
-  ignition::math::Vector3d center, minXYZ, maxXYZ;
-  this->GetMeshAABB(_mesh, center, minXYZ, maxXYZ);
-  _center = center;
-  _minXYZ = minXYZ;
-  _maxXYZ = maxXYZ;
-}
-
 //////////////////////////////////////////////////
 void MeshManager::GetMeshAABB(const Mesh *_mesh,
     ignition::math::Vector3d &_center,
@@ -214,12 +215,6 @@ void MeshManager::GetMeshAABB(const Mesh *_mesh,
     this->meshes[_mesh->GetName()]->GetAABB(_center, _minXYZ, _maxXYZ);
 }
 
-//////////////////////////////////////////////////
-void MeshManager::GenSphericalTexCoord(const Mesh *_mesh, math::Vector3 _center)
-{
-  this->GenSphericalTexCoord(_mesh, _center.Ign());
-}
-
 //////////////////////////////////////////////////
 void MeshManager::GenSphericalTexCoord(const Mesh *_mesh,
     const ignition::math::Vector3d &_center)
@@ -320,15 +315,6 @@ void MeshManager::CreateSphere(const std::string &name, float radius,
   }
 }
 
-//////////////////////////////////////////////////
-void MeshManager::CreatePlane(const std::string &_name,
-    const math::Plane &_plane,
-    const math::Vector2d &_segments,
-    const math::Vector2d &_uvTile)
-{
-  this->CreatePlane(_name, _plane.Ign(), _segments.Ign(), _uvTile.Ign());
-}
-
 //////////////////////////////////////////////////
 void MeshManager::CreatePlane(const std::string &_name,
     const ignition::math::Planed &_plane,
@@ -339,15 +325,6 @@ void MeshManager::CreatePlane(const std::string &_name,
       _segments, _uvTile);
 }
 
-//////////////////////////////////////////////////
-void MeshManager::CreatePlane(const std::string &_name,
-    const math::Vector3 &_normal, double _d, const math::Vector2d &_size,
-    const math::Vector2d &_segments, const math::Vector2d &_uvTile)
-{
-  this->CreatePlane(_name, _normal.Ign(), _d, _size.Ign(), _segments.Ign(),
-      _uvTile.Ign());
-}
-
 //////////////////////////////////////////////////
 void MeshManager::CreatePlane(const std::string &_name,
     const ignition::math::Vector3d &_normal,
@@ -424,13 +401,6 @@ void MeshManager::CreatePlane(const std::string &_name,
   this->Tesselate2DMesh(subMesh, _segments.X() + 1, _segments.Y() + 1, false);
 }
 
-//////////////////////////////////////////////////
-void MeshManager::CreateBox(const std::string &_name,
-    const math::Vector3 &_sides, const math::Vector2d &_uvCoords)
-{
-  this->CreateBox(_name, _sides.Ign(), _uvCoords.Ign());
-}
-
 //////////////////////////////////////////////////
 void MeshManager::CreateBox(const std::string &_name,
     const ignition::math::Vector3d &_sides,
@@ -533,22 +503,6 @@ void MeshManager::CreateBox(const std::string &_name,
     subMesh->AddIndex(ind[i]);
 }
 
-//////////////////////////////////////////////////
-void MeshManager::CreateExtrudedPolyline(const std::string &_name,
-    const std::vector<std::vector<math::Vector2d> > &_polys, double _height)
-{
-  std::vector<std::vector<ignition::math::Vector2d> > polys;
-  for (auto const &polyVec : _polys)
-  {
-    std::vector<ignition::math::Vector2d> newVec;
-    for (auto const &poly : polyVec)
-      newVec.push_back(poly.Ign());
-    polys.push_back(newVec);
-  }
-
-  this->CreateExtrudedPolyline(_name, polys, _height);
-}
-
 //////////////////////////////////////////////////
 void MeshManager::CreateExtrudedPolyline(const std::string &_name,
     const std::vector<std::vector<ignition::math::Vector2d> > &_polys,
@@ -586,7 +540,6 @@ void MeshManager::CreateExtrudedPolyline(const std::string &_name,
 
   Mesh *mesh = new Mesh();
   mesh->SetName(_name);
-  this->meshes.insert(std::make_pair(_name, mesh));
 
   SubMesh *subMesh = new SubMesh();
   mesh->AddSubMesh(subMesh);
@@ -691,6 +644,7 @@ void MeshManager::CreateExtrudedPolyline(const std::string &_name,
   if (normals.size() != edges.size())
   {
     gzerr << "Unable to extrude mesh. Triangulation failed" << std::endl;
+    delete mesh;
     return;
   }
 
@@ -761,6 +715,9 @@ void MeshManager::CreateExtrudedPolyline(const std::string &_name,
       subMesh->AddNormal(normals[i]);
     }
   }
+
+  this->meshes.insert(std::make_pair(_name, mesh));
+  return;
 }
 
 //////////////////////////////////////////////////
@@ -1321,13 +1278,6 @@ void MeshManager::Tesselate2DMesh(SubMesh *sm, int meshWidth, int meshHeight,
 }
 
 #ifdef HAVE_GTS
-//////////////////////////////////////////////////
-void MeshManager::CreateBoolean(const std::string &_name, const Mesh *_m1,
-    const Mesh *_m2, int _operation, const math::Pose &_offset)
-{
-  this->CreateBoolean(_name, _m1, _m2, _operation, _offset.Ign());
-}
-
 //////////////////////////////////////////////////
 void MeshManager::CreateBoolean(const std::string &_name, const Mesh *_m1,
     const Mesh *_m2, int _operation, const ignition::math::Pose3d &_offset)
