@@ -628,9 +628,12 @@ void ModelManipulator::OnMousePressEvent(const common::MouseEvent &_event)
 
   this->dataPtr->selectionObj->SetState(manipState);
 
+  // See issue #1510
+  bool keyIsPressed = (QApplication::keyboardModifiers() != Qt::NoModifier);
+
   // set the new mouse vis only if there are no modifier keys pressed and the
   // entity was different from the previously selected one.
-  if (!this->dataPtr->keyEvent.key && (this->dataPtr->selectionObj->GetMode() ==
+  if (!keyIsPressed && (this->dataPtr->selectionObj->GetMode() ==
        rendering::SelectionObj::SELECTION_NONE
       || (mouseVis && mouseVis != this->dataPtr->selectionObj->GetParent())))
   {
