@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2015 Open Source Robotics Foundation
+ * Copyright (C) 2014-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -52,8 +52,8 @@ ModelSnap::ModelSnap()
   this->dataPtr->initialized = false;
   this->dataPtr->selectedTriangleDirty = false;
   this->dataPtr->hoverTriangleDirty = false;
-  this->dataPtr->snapLines = NULL;
-  this->dataPtr->updateMutex = NULL;
+  this->dataPtr->snapLines = nullptr;
+  this->dataPtr->snapHighlight = nullptr;
 }
 
 /////////////////////////////////////////////////
@@ -64,6 +64,12 @@ ModelSnap::~ModelSnap()
   this->dataPtr = NULL;
 }
 
+/////////////////////////////////////////////////
+void ModelSnap::Fini()
+{
+  this->Clear();
+}
+
 /////////////////////////////////////////////////
 void ModelSnap::Clear()
 {
@@ -75,27 +81,29 @@ void ModelSnap::Clear()
   this->dataPtr->hoverVis.reset();
 
   this->dataPtr->node.reset();
-  this->dataPtr->modelPub.reset();
-
-  if (this->dataPtr->updateMutex)
-  {
-    boost::recursive_mutex::scoped_lock lock(*this->dataPtr->updateMutex);
-    delete this->dataPtr->snapLines;
-    this->dataPtr->snapLines = NULL;
-    this->dataPtr->snapVisual.reset();
-
-    if (this->dataPtr->snapHighlight != NULL &&
-        this->dataPtr->highlightVisual != NULL)
-    {
-      this->dataPtr->highlightVisual->
-          DeleteDynamicLine(this->dataPtr->snapHighlight);
-    }
-    this->dataPtr->highlightVisual.reset();
-  }
+  this->dataPtr->userCmdPub.reset();
 
   if (this->dataPtr->renderConnection)
+  {
     event::Events::DisconnectRender(this->dataPtr->renderConnection);
-  this->dataPtr->renderConnection.reset();
+    this->dataPtr->renderConnection.reset();
+  }
+
+  if (this->dataPtr->snapVisual)
+  {
+    this->dataPtr->snapVisual->DeleteDynamicLine(this->dataPtr->snapLines);
+    this->dataPtr->snapLines = nullptr;
+    this->dataPtr->snapVisual->Fini();
+    this->dataPtr->snapVisual.reset();
+  }
+  if (this->dataPtr->highlightVisual)
+  {
+    this->dataPtr->highlightVisual->DeleteDynamicLine(
+        this->dataPtr->snapHighlight);
+    this->dataPtr->snapHighlight = nullptr;
+    this->dataPtr->highlightVisual->Fini();
+    this->dataPtr->highlightVisual.reset();
+  }
 
   delete this->dataPtr->updateMutex;
   this->dataPtr->updateMutex = NULL;
@@ -127,8 +135,8 @@ void ModelSnap::Init()
 
   this->dataPtr->node = transport::NodePtr(new transport::Node());
   this->dataPtr->node->Init();
-  this->dataPtr->modelPub =
-      this->dataPtr->node->Advertise<msgs::Model>("~/model/modify");
+  this->dataPtr->userCmdPub =
+      this->dataPtr->node->Advertise<msgs::UserCmd>("~/user_cmd");
 
   this->dataPtr->rayQuery.reset(
       new rendering::RayQuery(this->dataPtr->userCamera));
@@ -153,25 +161,19 @@ void ModelSnap::Reset()
   {
     if (this->dataPtr->snapVisual->GetVisible())
       this->dataPtr->snapVisual->SetVisible(false);
-    if (this->dataPtr->snapVisual->GetParent())
-    {
-      this->dataPtr->snapVisual->GetParent()->DetachVisual(
-          this->dataPtr->snapVisual);
-    }
   }
 
   if (this->dataPtr->highlightVisual)
   {
-    this->dataPtr->highlightVisual->SetVisible(false);
-    if (this->dataPtr->highlightVisual->GetParent())
-    {
-      this->dataPtr->highlightVisual->GetParent()->DetachVisual(
-          this->dataPtr->highlightVisual);
-    }
+    if (this->dataPtr->highlightVisual->GetVisible())
+      this->dataPtr->highlightVisual->SetVisible(false);
   }
 
-  event::Events::DisconnectRender(this->dataPtr->renderConnection);
-  this->dataPtr->renderConnection.reset();
+  if (this->dataPtr->renderConnection)
+  {
+    event::Events::DisconnectRender(this->dataPtr->renderConnection);
+    this->dataPtr->renderConnection.reset();
+  }
 }
 
 /////////////////////////////////////////////////
@@ -351,15 +353,27 @@ void ModelSnap::PublishVisualPose(rendering::VisualPtr _vis)
   if (!_vis)
     return;
 
-  // Check to see if the visual is a model.
-  if (gui::get_entity_id(_vis->GetName()))
+  // Only publish for models
+  if (_vis->GetType() == gazebo::rendering::Visual::VT_MODEL)
   {
-    msgs::Model msg;
-    msg.set_id(gui::get_entity_id(_vis->GetName()));
-    msg.set_name(_vis->GetName());
+    // Register user command on server
+    msgs::UserCmd userCmdMsg;
+    userCmdMsg.set_description("Snap [" + _vis->GetName() + "]");
+    userCmdMsg.set_type(msgs::UserCmd::MOVING);
 
+    msgs::Model msg;
+
+    auto id = gui::get_entity_id(_vis->GetName());
+    if (id)
+      msg.set_id(id);
+
+    msg.set_name(_vis->GetName());
     msgs::Set(msg.mutable_pose(), _vis->GetWorldPose().Ign());
-    this->dataPtr->modelPub->Publish(msg);
+
+    auto modelMsg = userCmdMsg.add_model();
+    modelMsg->CopyFrom(msg);
+
+    this->dataPtr->userCmdPub->Publish(userCmdMsg);
   }
 }
 
@@ -387,14 +401,15 @@ void ModelSnap::Update()
         std::string highlightVisName = "_SNAP_HIGHLIGHT_";
         this->dataPtr->highlightVisual.reset(new rendering::Visual(
             highlightVisName, this->dataPtr->hoverVis, false));
+        this->dataPtr->highlightVisual->Load();
         this->dataPtr->snapHighlight =
             this->dataPtr->highlightVisual->CreateDynamicLine(
             rendering::RENDERING_TRIANGLE_FAN);
         this->dataPtr->snapHighlight->setMaterial("Gazebo/RedTransparent");
-        this->dataPtr->snapHighlight->AddPoint(hoverTriangle[0]);
-        this->dataPtr->snapHighlight->AddPoint(hoverTriangle[1]);
-        this->dataPtr->snapHighlight->AddPoint(hoverTriangle[2]);
-        this->dataPtr->snapHighlight->AddPoint(hoverTriangle[0]);
+        this->dataPtr->snapHighlight->AddPoint(hoverTriangle[0].Ign());
+        this->dataPtr->snapHighlight->AddPoint(hoverTriangle[1].Ign());
+        this->dataPtr->snapHighlight->AddPoint(hoverTriangle[2].Ign());
+        this->dataPtr->snapHighlight->AddPoint(hoverTriangle[0].Ign());
         this->dataPtr->highlightVisual->SetVisible(true);
         this->dataPtr->highlightVisual->GetSceneNode()->setInheritScale(false);
         this->dataPtr->highlightVisual->SetVisibilityFlags(
@@ -415,10 +430,10 @@ void ModelSnap::Update()
           }
           this->dataPtr->hoverVis->AttachVisual(this->dataPtr->highlightVisual);
         }
-        this->dataPtr->snapHighlight->SetPoint(0, hoverTriangle[0]);
-        this->dataPtr->snapHighlight->SetPoint(1, hoverTriangle[1]);
-        this->dataPtr->snapHighlight->SetPoint(2, hoverTriangle[2]);
-        this->dataPtr->snapHighlight->SetPoint(3, hoverTriangle[0]);
+        this->dataPtr->snapHighlight->SetPoint(0, hoverTriangle[0].Ign());
+        this->dataPtr->snapHighlight->SetPoint(1, hoverTriangle[1].Ign());
+        this->dataPtr->snapHighlight->SetPoint(2, hoverTriangle[2].Ign());
+        this->dataPtr->snapHighlight->SetPoint(3, hoverTriangle[0].Ign());
       }
     }
     else
@@ -450,15 +465,15 @@ void ModelSnap::Update()
       std::string snapVisName = "_SNAP_";
       this->dataPtr->snapVisual.reset(new rendering::Visual(
           snapVisName, this->dataPtr->selectedVis, false));
-
+      this->dataPtr->snapVisual->Load();
       this->dataPtr->snapLines =
           this->dataPtr->snapVisual->CreateDynamicLine(
           rendering::RENDERING_LINE_STRIP);
       this->dataPtr->snapLines->setMaterial("Gazebo/RedGlow");
-      this->dataPtr->snapLines->AddPoint(triangle[0]);
-      this->dataPtr->snapLines->AddPoint(triangle[1]);
-      this->dataPtr->snapLines->AddPoint(triangle[2]);
-      this->dataPtr->snapLines->AddPoint(triangle[0]);
+      this->dataPtr->snapLines->AddPoint(triangle[0].Ign());
+      this->dataPtr->snapLines->AddPoint(triangle[1].Ign());
+      this->dataPtr->snapLines->AddPoint(triangle[2].Ign());
+      this->dataPtr->snapLines->AddPoint(triangle[0].Ign());
       this->dataPtr->snapVisual->SetVisible(true);
       this->dataPtr->snapVisual->GetSceneNode()->setInheritScale(false);
       this->dataPtr->snapVisual->SetVisibilityFlags(
@@ -478,10 +493,10 @@ void ModelSnap::Update()
         }
         this->dataPtr->selectedVis->AttachVisual(this->dataPtr->snapVisual);
       }
-      this->dataPtr->snapLines->SetPoint(0, triangle[0]);
-      this->dataPtr->snapLines->SetPoint(1, triangle[1]);
-      this->dataPtr->snapLines->SetPoint(2, triangle[2]);
-      this->dataPtr->snapLines->SetPoint(3, triangle[0]);
+      this->dataPtr->snapLines->SetPoint(0, triangle[0].Ign());
+      this->dataPtr->snapLines->SetPoint(1, triangle[1].Ign());
+      this->dataPtr->snapLines->SetPoint(2, triangle[2].Ign());
+      this->dataPtr->snapLines->SetPoint(3, triangle[0].Ign());
     }
     this->dataPtr->selectedTriangleDirty = false;
   }
