@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2015 Open Source Robotics Foundation
+ * Copyright (C) 2012-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -43,6 +43,9 @@ QTestFixture::QTestFixture()
 /////////////////////////////////////////////////
 void QTestFixture::initTestCase()
 {
+  // Verbose mode
+  gazebo::common::Console::SetQuiet(false);
+
   // Initialize the informational logger. This will log warnings, and
   // errors.
   gzLogInit("qtest-", "test.log");
@@ -70,6 +73,9 @@ void QTestFixture::init()
   this->serverThread = NULL;
   this->GetMemInfo(this->residentStart, this->shareStart);
   gazebo::rendering::load();
+
+  if (!gazebo::gui::register_metatypes())
+    gzerr << "Unable to register Qt metatypes" << std::endl;
 }
 
 /////////////////////////////////////////////////
@@ -82,15 +88,26 @@ void QTestFixture::Load(const std::string &_worldFilename, bool _paused,
         _worldFilename, _paused, _serverScene));
 
   // Wait for the server to come up
-  // Use a 30 second timeout.
-  int waitCount = 0, maxWaitCount = 3000;
+  // Use a 60 second timeout.
+  int waitCount = 0, maxWaitCount = 6000;
   while ((!this->server || !this->server->GetInitialized()) &&
       ++waitCount < maxWaitCount)
     gazebo::common::Time::MSleep(10);
 
+  if (!this->server || !this->server->GetInitialized() ||
+      waitCount >= maxWaitCount)
+  {
+    gzerr << "Unable to initialize server. Potential reasons:" << std::endl;
+    gzerr << "\tIncorrect world name?" << std::endl;
+    gzerr << "\tConnection problem downloading models" << std::endl;
+    return;
+  }
+
   if (_clientScene)
+  {
     gazebo::rendering::create_scene(
         gazebo::physics::get_world()->GetName(), false);
+  }
 }
 
 /////////////////////////////////////////////////
@@ -119,6 +136,19 @@ void QTestFixture::SetPause(bool _pause)
   gazebo::physics::pause_worlds(_pause);
 }
 
+/////////////////////////////////////////////////
+void QTestFixture::ProcessEventsAndDraw(QMainWindow *_mainWindow,
+    const unsigned int _repeat, const unsigned int _ms)
+{
+  for (size_t i = 0; i < _repeat; ++i)
+  {
+    gazebo::common::Time::MSleep(_ms);
+    QCoreApplication::processEvents();
+    if (_mainWindow)
+      _mainWindow->repaint();
+  }
+}
+
 /////////////////////////////////////////////////
 void QTestFixture::cleanup()
 {
@@ -140,8 +170,7 @@ void QTestFixture::cleanup()
   double residentEnd, shareEnd;
   this->GetMemInfo(residentEnd, shareEnd);
 
-  // Calculate the percent change from the initial resident and shared
-  // memory
+  // Calculate the percent change from the initial resident and shared memory
   double resPercentChange = (residentEnd - residentStart) / residentStart;
   double sharePercentChange = (shareEnd - shareStart) / shareStart;
 
