@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Open Source Robotics Foundation
+ * Copyright (C) 2013-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,6 +21,7 @@
   #include <Winsock2.h>
 #endif
 #include <boost/filesystem.hpp>
+#include <tinyxml.h>
 
 #include "gazebo/common/SystemPaths.hh"
 #include "gazebo/common/Console.hh"
@@ -40,6 +41,8 @@ SaveDialog::SaveDialog(int _mode, QWidget *_parent)
 {
   this->setObjectName("saveDialog");
   this->setWindowTitle(tr("Save Model"));
+  this->setWindowFlags(Qt::Window | Qt::WindowCloseButtonHint |
+      Qt::WindowStaysOnTopHint | Qt::CustomizeWindowHint);
 
   this->dataPtr->messageLabel = new QLabel;
   this->dataPtr->messageLabel->setText(
@@ -123,6 +126,7 @@ SaveDialog::SaveDialog(int _mode, QWidget *_parent)
   locationLayout->addWidget(browseButton);
 
   QRadioButton *advancedOptionsCollapser = new QRadioButton();
+  advancedOptionsCollapser->setFocusPolicy(Qt::NoFocus);
   advancedOptionsCollapser->setChecked(false);
   advancedOptionsCollapser->setText("Advanced Options");
   advancedOptionsCollapser->setStyleSheet(
@@ -236,6 +240,8 @@ void SaveDialog::OnBrowse()
   fileDialog.setFileMode(QFileDialog::Directory);
   fileDialog.setOptions(QFileDialog::ShowDirsOnly
       | QFileDialog::DontResolveSymlinks);
+  fileDialog.setWindowFlags(Qt::Window | Qt::WindowCloseButtonHint |
+      Qt::WindowStaysOnTopHint | Qt::CustomizeWindowHint);
 
   if (fileDialog.exec() == QDialog::Accepted)
   {
