@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2015 Open Source Robotics Foundation
+ * Copyright (C) 2012-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,8 +17,11 @@
 #include <boost/bind.hpp>
 
 #include "gazebo/math/Angle.hh"
+
+#include "gazebo/common/Color.hh"
+
+#include "gazebo/gui/Conversions.hh"
 #include "gazebo/gui/building/ImportImageDialog.hh"
-#include "gazebo/gui/building/BuildingItem.hh"
 #include "gazebo/gui/building/GridLines.hh"
 #include "gazebo/gui/building/EditorItem.hh"
 #include "gazebo/gui/building/RectItem.hh"
@@ -287,8 +290,8 @@ void EditorView::mouseReleaseEvent(QMouseEvent *_event)
       {
         StairsItem *stairsItem = dynamic_cast<StairsItem *>(
             this->currentMouseItem);
-        stairsItem->Set3dTexture(QString(""));
-        stairsItem->Set3dColor(Qt::white);
+        stairsItem->SetTexture3d("");
+        stairsItem->SetColor3d(common::Color::White);
         this->stairsList.push_back(stairsItem);
         if ((this->currentLevel) < static_cast<int>(floorList.size()))
         {
@@ -348,21 +351,21 @@ void EditorView::mouseMoveEvent(QMouseEvent *_event)
                 (*it);
             if (anotherWall && anotherWall != wallSegmentItem)
             {
-              if (QVector2D(p2 - anotherWall->GetStartPoint()).length() <=
-                  distanceToClose)
+              if (ignition::math::Vector2d(Conversions::Convert(p2) -
+                  anotherWall->StartPoint()).Length() <= distanceToClose)
               {
-                pf = anotherWall->GetStartPoint();
-                this->snapGrabberOther = anotherWall->grabbers[0];
-                this->snapGrabberCurrent = wallSegmentItem->grabbers[1];
+                pf = Conversions::Convert(anotherWall->StartPoint());
+                this->snapGrabberOther = anotherWall->Grabbers()[0];
+                this->snapGrabberCurrent = wallSegmentItem->Grabbers()[1];
                 this->snapToGrabber = true;
                 break;
               }
-              else if (QVector2D(p2 - anotherWall->GetEndPoint()).length() <=
-                  distanceToClose)
+              else if (ignition::math::Vector2d(Conversions::Convert(p2) -
+                  anotherWall->EndPoint()).Length() <= distanceToClose)
               {
-                pf = anotherWall->GetEndPoint();
-                this->snapGrabberOther = anotherWall->grabbers[1];
-                this->snapGrabberCurrent = wallSegmentItem->grabbers[1];
+                pf = Conversions::Convert(anotherWall->EndPoint());
+                this->snapGrabberOther = anotherWall->Grabbers()[1];
+                this->snapGrabberCurrent = wallSegmentItem->Grabbers()[1];
                 this->snapToGrabber = true;
                 break;
               }
@@ -384,15 +387,15 @@ void EditorView::mouseMoveEvent(QMouseEvent *_event)
             // Snap to length increments
             double newLength = newLine.length();
             double lengthIncrement = SegmentItem::SnapLength /
-                wallSegmentItem->GetScale();
+                wallSegmentItem->Scale();
             newLength  = round(newLength/lengthIncrement)*lengthIncrement-
-                wallSegmentItem->GetThickness();
+                wallSegmentItem->Thickness();
 
             pf.setX(p1.x() + qCos(angle)*newLength);
             pf.setY(p1.y() + qSin(angle)*newLength);
           }
         }
-        wallSegmentItem->SetEndPoint(pf);
+        wallSegmentItem->SetEndPoint(Conversions::Convert(pf));
         wallSegmentItem->Update();
       }
       QApplication::setOverrideCursor(QCursor(Qt::CrossCursor));
@@ -426,8 +429,8 @@ void EditorView::mouseMoveEvent(QMouseEvent *_event)
   if (!grabber)
     grabber = this->currentMouseItem;
   RectItem *editorItem = dynamic_cast<RectItem *>(grabber);
-  if (grabber && editorItem && (editorItem->GetType() == "Window"
-      || editorItem->GetType() == "Door") )
+  if (grabber && editorItem && (editorItem->ItemType() == "Window"
+      || editorItem->ItemType() == "Door") )
   {
     if (grabber->parentItem())
     {
@@ -451,15 +454,15 @@ void EditorView::mouseMoveEvent(QMouseEvent *_event)
         double distance = fabs(deltaLineMouse2) / sqrt(deltaLine2);
         if (distance > 30 || t > 1.0 || t < 0.0)
         {
-          editorItem->setParentItem(NULL);
-          wallSegmentItem->setZValue(wallSegmentItem->zValueIdle);
+          editorItem->DetachFromParent();
+          wallSegmentItem->setZValue(wallSegmentItem->ZValueIdle());
           editorItem->SetPositionOnWall(0);
           editorItem->SetAngleOnWall(0);
-          this->buildingMaker->DetachManip(this->itemToVisualMap[editorItem],
-                this->itemToVisualMap[wallSegmentItem]);
-          editorItem->SetRotation(editorItem->GetRotation()
+          this->buildingMaker->DetachFromParent(
+              this->itemToVisualMap[editorItem]);
+          editorItem->SetRotation(editorItem->Rotation()
             - this->mousePressRotation);
-          editorItem->SetPosition(mousePoint);
+          editorItem->SetPosition(Conversions::Convert(mousePoint));
         }
         else
         {
@@ -494,11 +497,12 @@ void EditorView::mouseMoveEvent(QMouseEvent *_event)
               scenePos)))
           {
             editorItem->setParentItem(wallSegmentItem);
-            wallSegmentItem->setZValue(wallSegmentItem->zValueIdle+5);
+            wallSegmentItem->setZValue(wallSegmentItem->ZValueIdle()+5);
             this->buildingMaker->AttachManip(
                 this->itemToVisualMap[editorItem],
                 this->itemToVisualMap[wallSegmentItem]);
-            editorItem->SetPosition(wallSegmentItem->mapFromScene(scenePos));
+            editorItem->SetPosition(
+                Conversions::Convert(wallSegmentItem->mapFromScene(scenePos)));
             this->mousePressRotation = -wallSegmentItem->line().angle();
             editorItem->SetRotation(this->mousePressRotation);
 
@@ -575,7 +579,7 @@ void EditorView::mouseDoubleClickEvent(QMouseEvent *_event)
         this->currentMouseItem);
     this->itemToVisualMap.erase(wallSegmentItem);
 
-    this->UnlinkGrabbers(wallSegmentItem->grabbers[0]);
+    this->UnlinkGrabbers(wallSegmentItem->Grabbers()[0]);
 
     this->scene()->removeItem(this->currentMouseItem);
     delete this->currentMouseItem;
@@ -617,7 +621,7 @@ void EditorView::DeleteItem(EditorItem *_item)
 
   _item->SetHighlighted(false);
 
-  if (_item->GetType() == "WallSegment")
+  if (_item->ItemType() == "WallSegment")
   {
     WallSegmentItem *wallSegmentItem = dynamic_cast<WallSegmentItem *>(_item);
 
@@ -634,32 +638,32 @@ void EditorView::DeleteItem(EditorItem *_item)
       }
     }
 
-    this->UnlinkGrabbers(wallSegmentItem->grabbers[0]);
-    this->UnlinkGrabbers(wallSegmentItem->grabbers[1]);
+    this->UnlinkGrabbers(wallSegmentItem->Grabbers()[0]);
+    this->UnlinkGrabbers(wallSegmentItem->Grabbers()[1]);
 
     this->wallSegmentList.erase(std::remove(this->wallSegmentList.begin(),
         this->wallSegmentList.end(), dynamic_cast<WallSegmentItem *>(_item)),
         this->wallSegmentList.end());
   }
-  else if (_item->GetType() == "Window")
+  else if (_item->ItemType() == "Window")
   {
     this->windowList.erase(std::remove(this->windowList.begin(),
         this->windowList.end(), dynamic_cast<WindowItem *>(_item)),
         this->windowList.end());
   }
-  else if (_item->GetType() == "Door")
+  else if (_item->ItemType() == "Door")
   {
     this->doorList.erase(std::remove(this->doorList.begin(),
         this->doorList.end(), dynamic_cast<DoorItem *>(_item)),
         this->doorList.end());
   }
-  else if (_item->GetType() == "Stairs")
+  else if (_item->ItemType() == "Stairs")
   {
     this->stairsList.erase(std::remove(this->stairsList.begin(),
         this->stairsList.end(), dynamic_cast<StairsItem *>(_item)),
         this->stairsList.end());
   }
-  else if (_item->GetType() == "Floor")
+  else if (_item->ItemType() == "Floor")
   {
     this->floorList.erase(std::remove(this->floorList.begin(),
         this->floorList.end(), dynamic_cast<FloorItem *>(_item)),
@@ -678,8 +682,8 @@ void EditorView::DrawWall(const QPoint &_pos)
   // First point on the chain
   if (!this->drawInProgress)
   {
-    QPointF pointStart = mapToScene(_pos);
-    QPointF pointEnd = pointStart + QPointF(1, 0);
+    auto pointStart = Conversions::Convert(this->mapToScene(_pos));
+    auto pointEnd = pointStart + ignition::math::Vector2d(1, 0);
 
     wallSegmentItem = new WallSegmentItem(pointStart, pointEnd,
         this->levelDefaultHeight);
@@ -690,30 +694,30 @@ void EditorView::DrawWall(const QPoint &_pos)
 
       // Snap to other walls' points
       QList<QGraphicsItem *> itemsList = this->scene()->items(QRectF(
-          QPointF(pointStart.x() - distanceToClose/2,
-                  pointStart.y() - distanceToClose/2),
-          QPointF(pointStart.x() + distanceToClose/2,
-                  pointStart.y() + distanceToClose/2)));
+          QPointF(pointStart.X() - distanceToClose/2,
+                  pointStart.Y() - distanceToClose/2),
+          QPointF(pointStart.X() + distanceToClose/2,
+                  pointStart.Y() + distanceToClose/2)));
       for (QList<QGraphicsItem *>::iterator it = itemsList.begin();
           it  != itemsList.end(); ++it)
       {
         WallSegmentItem *anotherWall = dynamic_cast<WallSegmentItem *>(*it);
         if (anotherWall)
         {
-          if (QVector2D(pointStart - anotherWall->GetStartPoint()).length()
-              <= distanceToClose)
+          if (ignition::math::Vector2d(pointStart -
+              anotherWall->StartPoint()).Length() <= distanceToClose)
           {
-            wallSegmentItem->SetStartPoint(anotherWall->GetStartPoint());
-            this->LinkGrabbers(anotherWall->grabbers[0],
-                wallSegmentItem->grabbers[0]);
+            wallSegmentItem->SetStartPoint(anotherWall->StartPoint());
+            this->LinkGrabbers(anotherWall->Grabbers()[0],
+                wallSegmentItem->Grabbers()[0]);
             break;
           }
-          else if (QVector2D(pointStart - anotherWall->GetEndPoint()).length()
-              <= distanceToClose)
+          else if (ignition::math::Vector2d(pointStart -
+              anotherWall->EndPoint()).Length() <= distanceToClose)
           {
-            wallSegmentItem->SetStartPoint(anotherWall->GetEndPoint());
-            this->LinkGrabbers(anotherWall->grabbers[1],
-                wallSegmentItem->grabbers[0]);
+            wallSegmentItem->SetStartPoint(anotherWall->EndPoint());
+            this->LinkGrabbers(anotherWall->Grabbers()[1],
+                wallSegmentItem->Grabbers()[0]);
             break;
           }
         }
@@ -743,20 +747,20 @@ void EditorView::DrawWall(const QPoint &_pos)
     this->snapGrabberCurrent = NULL;
 
     wallSegmentItem = dynamic_cast<WallSegmentItem*>(this->currentMouseItem);
-    wallSegmentItem->Set3dTexture(QString(""));
-    wallSegmentItem->Set3dColor(Qt::white);
+    wallSegmentItem->SetTexture3d("");
+    wallSegmentItem->SetColor3d(common::Color::White);
     wallSegmentItem->SetHighlighted(false);
-    wallSegmentList.push_back(wallSegmentItem);
-    if (wallSegmentItem->GetLevel() > 0)
+    this->wallSegmentList.push_back(wallSegmentItem);
+    if (wallSegmentItem->Level() > 0)
     {
-      floorList[wallSegmentItem->GetLevel()-1]->AttachWallSegment(
+      floorList[wallSegmentItem->Level()-1]->AttachWallSegment(
           wallSegmentItem);
     }
 
     // Start from previous segment's end
-    QPointF newPointStart = wallSegmentItem->GetEndPoint();
-    QPointF newPointEnd = newPointStart + QPointF(1, 0);
-    GrabberHandle *grabberStart = wallSegmentItem->grabbers[1];
+    auto newPointStart = wallSegmentItem->EndPoint();
+    auto newPointEnd = newPointStart + ignition::math::Vector2d(1, 0);
+    GrabberHandle *grabberStart = wallSegmentItem->Grabbers()[1];
 
     wallSegmentItem = new WallSegmentItem(newPointStart,
         newPointEnd, this->levelDefaultHeight);
@@ -766,7 +770,7 @@ void EditorView::DrawWall(const QPoint &_pos)
     this->scene()->addItem(wallSegmentItem);
     this->currentMouseItem = wallSegmentItem;
 
-    this->LinkGrabbers(grabberStart, wallSegmentItem->grabbers[0]);
+    this->LinkGrabbers(grabberStart, wallSegmentItem->Grabbers()[0]);
   }
 
   // 3D counterpart
@@ -846,44 +850,44 @@ void EditorView::DrawStairs(const QPoint &_pos)
 /////////////////////////////////////////////////
 void EditorView::Create3DVisual(EditorItem *_item)
 {
-  QVector3D itemPosition = _item->GetScenePosition();
-  itemPosition.setZ(_item->GetLevelBaseHeight() + itemPosition.z());
-  QVector3D itemSize = _item->GetSize();
+  QVector3D itemPosition = Conversions::Convert(_item->ScenePosition());
+  itemPosition.setZ(_item->LevelBaseHeight() + itemPosition.z());
+  QVector3D itemSize = Conversions::Convert(_item->Size());
   std::string itemName;
 
-  if (_item->GetType() == "Stairs")
+  if (_item->ItemType() == "Stairs")
   {
     StairsItem *stairsItem = dynamic_cast<StairsItem *>(_item);
     itemName = this->buildingMaker->AddStairs(
-        itemSize, itemPosition, _item->GetSceneRotation(),
-        stairsItem->GetSteps());
-    if (stairsItem->GetLevel() < static_cast<int>(floorList.size()))
+        itemSize, itemPosition, _item->SceneRotation(),
+        stairsItem->Steps());
+    if (stairsItem->Level() < static_cast<int>(floorList.size()))
     {
       this->buildingMaker->AttachManip(itemName,
-          this->itemToVisualMap[floorList[stairsItem->GetLevel()]]);
+          this->itemToVisualMap[floorList[stairsItem->Level()]]);
     }
   }
-  else if (_item->GetType() == "WallSegment")
+  else if (_item->ItemType() == "WallSegment")
   {
     WallSegmentItem *wallSegmentItem = dynamic_cast<WallSegmentItem *>(_item);
-    itemSize.setZ(wallSegmentItem->GetHeight());
+    itemSize.setZ(wallSegmentItem->Height());
     itemName = this->buildingMaker->AddWall(
-        itemSize, itemPosition, _item->GetSceneRotation());
+        itemSize, itemPosition, _item->SceneRotation());
   }
-  else if (_item->GetType() == "Window")
+  else if (_item->ItemType() == "Window")
   {
     itemName = this->buildingMaker->AddWindow(
-        itemSize, itemPosition, _item->GetSceneRotation());
+        itemSize, itemPosition, _item->SceneRotation());
   }
-  else if (_item->GetType() == "Door")
+  else if (_item->ItemType() == "Door")
   {
     itemName = this->buildingMaker->AddDoor(
-        itemSize, itemPosition, _item->GetSceneRotation());
+        itemSize, itemPosition, _item->SceneRotation());
   }
-  else if (_item->GetType() == "Floor")
+  else if (_item->ItemType() == "Floor")
   {
     itemName = this->buildingMaker->AddFloor(
-        itemSize, _item->GetScenePosition(), 0);
+        itemSize, Conversions::Convert(_item->ScenePosition()), 0);
   }
   this->buildingMaker->ConnectItem(itemName, _item);
   this->itemToVisualMap[_item] = itemName;
@@ -1052,18 +1056,18 @@ void EditorView::OnAddLevel()
 
   std::vector<WallSegmentItem *>::iterator wallIt =
       this->wallSegmentList.begin();
-  double wallHeight = (*wallIt)->GetHeight() + (*wallIt)->GetLevelBaseHeight();
+  double wallHeight = (*wallIt)->Height() + (*wallIt)->LevelBaseHeight();
   double maxHeight = wallHeight;
   int wallLevel = 0;
 
   ++wallIt;
   for (wallIt; wallIt != this->wallSegmentList.end(); ++wallIt)
   {
-    wallHeight = (*wallIt)->GetHeight() + (*wallIt)->GetLevelBaseHeight();
+    wallHeight = (*wallIt)->Height() + (*wallIt)->LevelBaseHeight();
     if ( wallHeight > maxHeight)
     {
       maxHeight = wallHeight;
-      wallLevel = (*wallIt)->GetLevel();
+      wallLevel = (*wallIt)->Level();
     }
   }
   newLevel->baseHeight = maxHeight;
@@ -1075,7 +1079,7 @@ void EditorView::OnAddLevel()
   for (std::vector<WallSegmentItem *>::iterator it = wallSegmentList.begin();
       it  != this->wallSegmentList.end(); ++it)
   {
-    if ((*it)->GetLevel() != wallLevel)
+    if ((*it)->Level() != wallLevel)
       continue;
 
     WallSegmentItem *wallSegmentItem = (*it)->Clone();
@@ -1089,8 +1093,8 @@ void EditorView::OnAddLevel()
     this->Create3DVisual(wallSegmentItem);
 
     floorItem->AttachWallSegment(wallSegmentItem);
-    wallSegmentItem->Set3dTexture(QString(""));
-    wallSegmentItem->Set3dColor(Qt::white);
+    wallSegmentItem->SetTexture3d("");
+    wallSegmentItem->SetColor3d(common::Color::White);
     wallSegmentItem->SetHighlighted(false);
   }
 
@@ -1105,15 +1109,15 @@ void EditorView::OnAddLevel()
     // start / end
     for (int g = 0; g < 2; ++g)
     {
-      for (unsigned int i = 0; i < oldWall->grabbers[g]->linkedGrabbers.size();
-          ++i)
+      for (auto oldGrabber : oldWall->Grabbers()[g]->LinkedGrabbers())
       {
         WallSegmentItem *parentItem = dynamic_cast<WallSegmentItem*>(
-            oldWall->grabbers[g]->linkedGrabbers[i]->parentItem());
-        int index = oldWall->grabbers[g]->linkedGrabbers[i]->GetIndex();
+            oldGrabber->parentItem());
 
-        newWall->grabbers[g]->linkedGrabbers.push_back(
-            clonedWallMap[parentItem]->grabbers[index]);
+        int index = oldGrabber->Index();
+
+        newWall->Grabbers()[g]->PushLinkedGrabber(
+            clonedWallMap[parentItem]->Grabbers()[index]);
       }
     }
   }
@@ -1127,16 +1131,16 @@ void EditorView::OnAddLevel()
   for (std::vector<StairsItem *>::iterator it = this->stairsList.begin();
       it != this->stairsList.end(); ++it)
   {
-    if ((*it)->GetLevel() == (newLevelNum - 1))
+    if ((*it)->Level() == (newLevelNum - 1))
     {
       buildingMaker->AttachManip(this->itemToVisualMap[(*it)],
-          floorItem->GetName());
+          floorItem->Name());
     }
   }
   this->scene()->addItem(floorItem);
   this->floorList.push_back(floorItem);
-  floorItem->Set3dTexture(QString(""));
-  floorItem->Set3dColor(Qt::white);
+  floorItem->SetTexture3d("");
+  floorItem->SetColor3d(common::Color::White);
   floorItem->SetHighlighted(false);
 }
 
@@ -1172,48 +1176,48 @@ void EditorView::DeleteLevel(int _level)
   for (std::vector<WindowItem *>::iterator it = this->windowList.begin();
       it != this->windowList.end(); ++it)
   {
-    if ((*it)->GetLevel() == _level)
+    if ((*it)->Level() == _level)
       toBeDeleted.push_back(*it);
-    else if ((*it)->GetLevel() > _level)
+    else if ((*it)->Level() > _level)
     {
-      (*it)->SetLevel((*it)->GetLevel()-1);
-      (*it)->SetLevelBaseHeight((*it)->GetLevelBaseHeight() - deletedHeight);
+      (*it)->SetLevel((*it)->Level()-1);
+      (*it)->SetLevelBaseHeight((*it)->LevelBaseHeight() - deletedHeight);
       (*it)->WindowChanged();
     }
   }
   for (std::vector<DoorItem *>::iterator it = this->doorList.begin();
       it != this->doorList.end(); ++it)
   {
-    if ((*it)->GetLevel() == _level)
+    if ((*it)->Level() == _level)
       toBeDeleted.push_back(*it);
-    else if ((*it)->GetLevel() > _level)
+    else if ((*it)->Level() > _level)
     {
-      (*it)->SetLevel((*it)->GetLevel()-1);
-      (*it)->SetLevelBaseHeight((*it)->GetLevelBaseHeight()-deletedHeight);
+      (*it)->SetLevel((*it)->Level()-1);
+      (*it)->SetLevelBaseHeight((*it)->LevelBaseHeight()-deletedHeight);
       (*it)->DoorChanged();
     }
   }
   for (std::vector<StairsItem *>::iterator it = this->stairsList.begin();
       it != this->stairsList.end(); ++it)
   {
-    if ((*it)->GetLevel() == _level)
+    if ((*it)->Level() == _level)
       toBeDeleted.push_back(*it);
-    else if ((*it)->GetLevel() > _level)
+    else if ((*it)->Level() > _level)
     {
-      (*it)->SetLevel((*it)->GetLevel()-1);
-      (*it)->SetLevelBaseHeight((*it)->GetLevelBaseHeight()-deletedHeight);
+      (*it)->SetLevel((*it)->Level()-1);
+      (*it)->SetLevelBaseHeight((*it)->LevelBaseHeight()-deletedHeight);
       (*it)->StairsChanged();
     }
   }
   for (std::vector<FloorItem *>::iterator it = this->floorList.begin();
       it != this->floorList.end(); ++it)
   {
-    if ((*it)->GetLevel() == _level)
+    if ((*it)->Level() == _level)
       toBeDeleted.push_back(*it);
-    else if ((*it)->GetLevel() > _level)
+    else if ((*it)->Level() > _level)
     {
-      (*it)->SetLevel((*it)->GetLevel()-1);
-      (*it)->SetLevelBaseHeight((*it)->GetLevelBaseHeight()-deletedHeight);
+      (*it)->SetLevel((*it)->Level()-1);
+      (*it)->SetLevelBaseHeight((*it)->LevelBaseHeight()-deletedHeight);
       (*it)->FloorChanged();
     }
   }
@@ -1221,12 +1225,12 @@ void EditorView::DeleteLevel(int _level)
       this->wallSegmentList.begin();
       it != this->wallSegmentList.end(); ++it)
   {
-    if ((*it)->GetLevel() == _level)
+    if ((*it)->Level() == _level)
       toBeDeleted.push_back(*it);
-    else if ((*it)->GetLevel() > _level)
+    else if ((*it)->Level() > _level)
     {
-      (*it)->SetLevel((*it)->GetLevel()-1);
-      (*it)->SetLevelBaseHeight((*it)->GetLevelBaseHeight()-deletedHeight);
+      (*it)->SetLevel((*it)->Level()-1);
+      (*it)->SetLevelBaseHeight((*it)->LevelBaseHeight()-deletedHeight);
       (*it)->WallSegmentChanged();
     }
   }
@@ -1262,6 +1266,9 @@ void EditorView::OnChangeLevel(int _level)
   if (_level < 0)
     return;
 
+  if (this->currentLevel >= static_cast<int>(this->levels.size()))
+    return;
+
   if (this->levels[this->currentLevel]->backgroundPixmap)
     this->levels[this->currentLevel]->backgroundPixmap->setVisible(false);
 
@@ -1283,13 +1290,13 @@ void EditorView::OnOpenLevelInspector()
   FloorItem *floorItem = this->levels[this->currentLevel]->floorItem;
   if (floorItem)
   {
-    this->levelInspector->floorWidget->show();
-    this->levelInspector->SetColor(floorItem->Get3dColor());
-    this->levelInspector->SetTexture(floorItem->Get3dTexture());
+    this->levelInspector->ShowFloorWidget(true);
+    this->levelInspector->SetColor(floorItem->Color3d());
+    this->levelInspector->SetTexture(floorItem->Texture3d());
   }
   else
   {
-    this->levelInspector->floorWidget->hide();
+    this->levelInspector->ShowFloorWidget(false);
   }
   this->levelInspector->move(QCursor::pos());
   this->levelInspector->show();
@@ -1301,13 +1308,13 @@ void EditorView::OnLevelApply()
   LevelInspectorDialog *dialog =
       qobject_cast<LevelInspectorDialog *>(QObject::sender());
 
-  std::string newLevelName = dialog->GetLevelName();
+  std::string newLevelName = dialog->LevelName();
   this->levels[this->currentLevel]->name = newLevelName;
   FloorItem *floorItem = this->levels[this->currentLevel]->floorItem;
   if (floorItem)
   {
-    floorItem->Set3dTexture(dialog->GetTexture());
-    floorItem->Set3dColor(dialog->GetColor());
+    floorItem->SetTexture3d(dialog->Texture());
+    floorItem->SetColor3d(dialog->Color());
     floorItem->Set3dTransparency(0.4);
     floorItem->FloorChanged();
   }
@@ -1328,7 +1335,7 @@ void EditorView::CancelDrawMode()
 
       if (wallSegmentItem)
       {
-        this->UnlinkGrabbers(wallSegmentItem->grabbers[0]);
+        this->UnlinkGrabbers(wallSegmentItem->Grabbers()[0]);
       }
       this->scene()->removeItem(this->currentMouseItem);
       delete this->currentMouseItem;
@@ -1367,7 +1374,7 @@ void EditorView::ShowCurrentLevelItems()
   for (std::vector<WallSegmentItem *>::iterator it =
       this->wallSegmentList.begin(); it != this->wallSegmentList.end(); ++it)
   {
-    if ((*it)->GetLevel() != this->currentLevel)
+    if ((*it)->Level() != this->currentLevel)
       (*it)->setVisible(false);
     else
       (*it)->setVisible(this->elementsVisible);
@@ -1375,7 +1382,7 @@ void EditorView::ShowCurrentLevelItems()
   for (std::vector<WindowItem *>::iterator it = this->windowList.begin();
       it != this->windowList.end(); ++it)
   {
-    if ((*it)->GetLevel() != this->currentLevel)
+    if ((*it)->Level() != this->currentLevel)
       (*it)->setVisible(false);
     else
       (*it)->setVisible(this->elementsVisible);
@@ -1383,7 +1390,7 @@ void EditorView::ShowCurrentLevelItems()
   for (std::vector<DoorItem *>::iterator it = this->doorList.begin();
       it != this->doorList.end(); ++it)
   {
-    if ((*it)->GetLevel() != this->currentLevel)
+    if ((*it)->Level() != this->currentLevel)
       (*it)->setVisible(false);
     else
       (*it)->setVisible(this->elementsVisible);
@@ -1391,7 +1398,7 @@ void EditorView::ShowCurrentLevelItems()
   for (std::vector<StairsItem *>::iterator it = this->stairsList.begin();
       it != this->stairsList.end(); ++it)
   {
-    if ((*it)->GetLevel() != this->currentLevel && (*it)->GetLevel() !=
+    if ((*it)->Level() != this->currentLevel && (*it)->Level() !=
         (this->currentLevel - 1))
       (*it)->setVisible(false);
     else
@@ -1400,7 +1407,7 @@ void EditorView::ShowCurrentLevelItems()
   for (std::vector<FloorItem *>::iterator it = this->floorList.begin();
       it != this->floorList.end(); ++it)
   {
-    if ((*it)->GetLevel() != this->currentLevel)
+    if ((*it)->Level() != this->currentLevel)
       (*it)->setVisible(false);
     else
       (*it)->setVisible(this->elementsVisible);
@@ -1414,29 +1421,27 @@ void EditorView::LinkGrabbers(GrabberHandle *_grabber1,
   if (_grabber1 && _grabber2 && _grabber1 != _grabber2)
   {
     // if _grabber2 is not yet linked to _grabber1
-    if (std::find(_grabber1->linkedGrabbers.begin(),
-                  _grabber1->linkedGrabbers.end(), _grabber2) ==
-                  _grabber1->linkedGrabbers.end())
+    auto linked1 = _grabber1->LinkedGrabbers();
+    auto linked2 = _grabber2->LinkedGrabbers();
+    if (std::find(linked1.begin(), linked1.end(), _grabber2) == linked1.end())
     {
       // Add _grabber2 so it moves when _grabber1 is moved
-      _grabber1->linkedGrabbers.push_back(_grabber2);
+      _grabber1->PushLinkedGrabber(_grabber2);
       // also link _grabber1 to all grabbers already linked to _grabber2
-      for (unsigned int i2 = 0; i2 < _grabber2->linkedGrabbers.size(); ++i2)
+      for (auto it : linked2)
       {
-        this->LinkGrabbers(_grabber1, _grabber2->linkedGrabbers[i2]);
+        this->LinkGrabbers(_grabber1, it);
       }
     }
     // if _grabber1 is not yet linked to _grabber2
-    if (std::find(_grabber2->linkedGrabbers.begin(),
-                  _grabber2->linkedGrabbers.end(), _grabber1) ==
-                  _grabber2->linkedGrabbers.end())
+    if (std::find(linked2.begin(), linked2.end(), _grabber1) == linked2.end())
     {
       // Add _grabber1 so it moves when _grabber2 is moved
-      _grabber2->linkedGrabbers.push_back(_grabber1);
+      _grabber2->PushLinkedGrabber(_grabber1);
       // also link _grabber2 to all grabbers already linked to _grabber1
-      for (unsigned int i1 = 0; i1 < _grabber1->linkedGrabbers.size(); ++i1)
+      for (auto it : linked1)
       {
-        this->LinkGrabbers(_grabber2, _grabber1->linkedGrabbers[i1]);
+        this->LinkGrabbers(_grabber2, it);
       }
     }
   }
@@ -1449,12 +1454,9 @@ void EditorView::UnlinkGrabbers(GrabberHandle *_grabber1,
   // If only one grabber, erase it from all grabbers it is linked
   if (!_grabber2)
   {
-    for (unsigned int i = 0; i < _grabber1->linkedGrabbers.size(); ++i)
+    for (auto linked : _grabber1->LinkedGrabbers())
     {
-      _grabber1->linkedGrabbers[i]->linkedGrabbers.erase(
-          std::remove(_grabber1->linkedGrabbers[i]->linkedGrabbers.begin(),
-          _grabber1->linkedGrabbers[i]->linkedGrabbers.end(), _grabber1),
-          _grabber1->linkedGrabbers[i]->linkedGrabbers.end());
+      linked->EraseLinkedGrabber(_grabber1);
     }
   }
 
