@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Open Source Robotics Foundation
+ * Copyright (C) 2013-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -27,10 +27,12 @@ ImportDialog::ImportDialog(QWidget *_parent) : QDialog(_parent)
 {
   this->setObjectName("ImportDialog");
   this->setWindowTitle("Import Link");
+  this->setWindowFlags(Qt::Window | Qt::WindowCloseButtonHint |
+      Qt::WindowStaysOnTopHint | Qt::CustomizeWindowHint);
 
   this->messageLabel = new QLabel;
   this->messageLabel->setText(
-      tr("You can import a 3D mesh (.dae, .stl) \n"
+      tr("You can import a 3D mesh (.dae, .stl, .obj) \n"
       "that you have made with a modelling tool \n"
       "such as Blender, Maya or SolidWorks.\n\n"
       "You can also extrude a 2D image (.svg) to \n"
@@ -69,6 +71,7 @@ ImportDialog::ImportDialog(QWidget *_parent) : QDialog(_parent)
   mainLayout->addLayout(buttonsLayout);
 
   this->setLayout(mainLayout);
+  this->layout()->setSizeConstraint(QLayout::SetFixedSize);
 }
 
 /////////////////////////////////////////////////
@@ -110,7 +113,9 @@ void ImportDialog::SetTitle(const std::string &_title)
 void ImportDialog::OnBrowse()
 {
   QFileDialog fd(this, tr("Import Link"), QDir::homePath(),
-      tr("Files (*.svg *.dae *.stl)"));
+      tr("Files (*.svg *.dae *.stl *.obj)"));
+  fd.setWindowFlags(Qt::Window | Qt::WindowCloseButtonHint |
+      Qt::WindowStaysOnTopHint | Qt::CustomizeWindowHint);
   fd.setFilter(QDir::AllDirs | QDir::Hidden);
   fd.setFileMode(QFileDialog::ExistingFile);
   if (fd.exec())
@@ -136,12 +141,16 @@ void ImportDialog::OnCancel()
 void ImportDialog::OnImport()
 {
   QFileInfo info(this->pathLineEdit->text());
-  if (info.isFile() && (info.completeSuffix().toLower() == "dae" ||
-      info.completeSuffix().toLower() == "stl"))
+
+  std::string suffix;
+  if (info.isFile())
+    suffix = info.completeSuffix().toLower().toStdString();
+
+  if (suffix == "dae" || suffix == "stl" || suffix == "obj")
   {
     this->accept();
   }
-  else if (info.completeSuffix().toLower() == "svg")
+  else if (suffix == "svg")
   {
     // Check if the SVG has any paths before accepting
     std::string filename = this->pathLineEdit->text().toStdString();
