@@ -62,27 +62,69 @@ LinkInspector::LinkInspector(QWidget *_parent) : QDialog(_parent),
   this->dataPtr->tabWidget->addTab(this->dataPtr->visualConfig, "Visual");
   this->dataPtr->tabWidget->addTab(this->dataPtr->collisionConfig, "Collision");
 
-  // Buttons
+  // Show collisions button
+  auto showCollisionsButton = new QToolButton(this);
+  showCollisionsButton->setObjectName("showCollisionsButton");
+  showCollisionsButton->setFixedSize(QSize(40, 40));
+  showCollisionsButton->setToolTip("Show/hide all collisions");
+  showCollisionsButton->setIcon(QPixmap(":/images/eye_collision.svg"));
+  showCollisionsButton->setToolButtonStyle(Qt::ToolButtonIconOnly);
+  showCollisionsButton->setIconSize(QSize(25, 25));
+  showCollisionsButton->setCheckable(true);
+  this->connect(showCollisionsButton, SIGNAL(toggled(const bool)), this,
+      SLOT(OnShowCollisions(const bool)));
+
+  // Show visuals button
+  auto showVisualsButton = new QToolButton(this);
+  showVisualsButton->setObjectName("showVisualsButton");
+  showVisualsButton->setFixedSize(QSize(40, 40));
+  showVisualsButton->setToolTip("Show/hide all visuals");
+  showVisualsButton->setIcon(QPixmap(":/images/eye_visual.svg"));
+  showVisualsButton->setToolButtonStyle(Qt::ToolButtonIconOnly);
+  showVisualsButton->setIconSize(QSize(25, 25));
+  showVisualsButton->setCheckable(true);
+  this->connect(showVisualsButton, SIGNAL(toggled(const bool)), this,
+      SLOT(OnShowVisuals(const bool)));
+
+  // Show link frame button
+  auto showLinkFrameButton = new QToolButton(this);
+  showLinkFrameButton->setObjectName("showLinkFrameButton");
+  showLinkFrameButton->setFixedSize(QSize(40, 40));
+  showLinkFrameButton->setToolTip("Show/hide link frame");
+  showLinkFrameButton->setIcon(QPixmap(":/images/eye_frame.svg"));
+  showLinkFrameButton->setToolButtonStyle(Qt::ToolButtonIconOnly);
+  showLinkFrameButton->setIconSize(QSize(25, 25));
+  showLinkFrameButton->setCheckable(true);
+  this->connect(showLinkFrameButton, SIGNAL(toggled(const bool)), this,
+      SLOT(OnShowLinkFrame(const bool)));
+
+  // Remove button
   QToolButton *removeButton = new QToolButton(this);
-  removeButton->setFixedSize(QSize(30, 30));
+  removeButton->setFixedSize(QSize(40, 40));
   removeButton->setToolTip("Remove link");
   removeButton->setIcon(QPixmap(":/images/trashcan.png"));
   removeButton->setToolButtonStyle(Qt::ToolButtonIconOnly);
-  removeButton->setIconSize(QSize(16, 16));
+  removeButton->setIconSize(QSize(25, 25));
   removeButton->setCheckable(false);
   connect(removeButton, SIGNAL(clicked()), this, SLOT(OnRemove()));
 
+  // Reset button
   QPushButton *resetButton = new QPushButton(tr("Reset"));
   connect(resetButton, SIGNAL(clicked()), this, SLOT(RestoreOriginalData()));
 
+  // Cancel button
   QPushButton *cancelButton = new QPushButton(tr("Cancel"));
   connect(cancelButton, SIGNAL(clicked()), this, SLOT(OnCancel()));
 
+  // Ok button
   QPushButton *OKButton = new QPushButton(tr("OK"));
   connect(OKButton, SIGNAL(clicked()), this, SLOT(OnOK()));
 
   QHBoxLayout *buttonsLayout = new QHBoxLayout;
   buttonsLayout->addWidget(removeButton);
+  buttonsLayout->addWidget(showLinkFrameButton);
+  buttonsLayout->addWidget(showVisualsButton);
+  buttonsLayout->addWidget(showCollisionsButton);
   buttonsLayout->addStretch(5);
   buttonsLayout->addWidget(resetButton);
   buttonsLayout->addWidget(cancelButton);
@@ -142,6 +184,51 @@ void LinkInspector::OnRemove()
   model::Events::requestLinkRemoval(this->dataPtr->linkId);
 }
 
+/////////////////////////////////////////////////
+void LinkInspector::OnShowCollisions(const bool _show)
+{
+  this->ShowCollisions(_show);
+}
+
+/////////////////////////////////////////////////
+void LinkInspector::SetShowCollisions(const bool _show)
+{
+  auto button = this->findChild<QToolButton *>("showCollisionsButton");
+
+  if (button)
+    button->setChecked(_show);
+}
+
+/////////////////////////////////////////////////
+void LinkInspector::OnShowVisuals(const bool _show)
+{
+  this->ShowVisuals(_show);
+}
+
+/////////////////////////////////////////////////
+void LinkInspector::SetShowVisuals(const bool _show)
+{
+  auto button = this->findChild<QToolButton *>("showVisualsButton");
+
+  if (button)
+    button->setChecked(_show);
+}
+
+/////////////////////////////////////////////////
+void LinkInspector::OnShowLinkFrame(const bool _show)
+{
+  this->ShowLinkFrame(_show);
+}
+
+/////////////////////////////////////////////////
+void LinkInspector::SetShowLinkFrame(const bool _show)
+{
+  auto button = this->findChild<QToolButton *>("showLinkFrameButton");
+
+  if (button)
+    button->setChecked(_show);
+}
+
 /////////////////////////////////////////////////
 void LinkInspector::OnCancel()
 {
