@@ -197,6 +197,25 @@ namespace gazebo
       _s->set_elevation(_v.GetElevationReference());
     }
 
+    /////////////////////////////////////////////////
+    void Set(msgs::Inertial *_i, const ignition::math::MassMatrix3d &_m)
+    {
+      _i->set_mass(_m.Mass());
+      _i->set_ixx(_m.IXX());
+      _i->set_iyy(_m.IYY());
+      _i->set_izz(_m.IZZ());
+      _i->set_ixy(_m.IXY());
+      _i->set_ixz(_m.IXZ());
+      _i->set_iyz(_m.IYZ());
+    }
+
+    /////////////////////////////////////////////////
+    void Set(msgs::Inertial *_i, const ignition::math::Inertiald &_m)
+    {
+      msgs::Set(_i, _m.MassMatrix());
+      msgs::Set(_i->mutable_pose(), _m.Pose());
+    }
+
     /////////////////////////////////////////////////
     void Set(msgs::PlaneGeom *_p, const ignition::math::Planed &_v)
     {
@@ -234,6 +253,96 @@ namespace gazebo
       }
     }
 
+    /////////////////////////////////////////////////
+    msgs::Any ConvertAny(const double _d)
+    {
+      msgs::Any result;
+      result.set_type(msgs::Any::DOUBLE);
+      result.set_double_value(_d);
+      return result;
+    }
+
+    /////////////////////////////////////////////////
+    msgs::Any ConvertAny(const int _i)
+    {
+      msgs::Any result;
+      result.set_type(msgs::Any::INT32);
+      result.set_int_value(_i);
+      return result;
+    }
+
+    /////////////////////////////////////////////////
+    msgs::Any ConvertAny(const std::string &_s)
+    {
+      msgs::Any result;
+      result.set_type(msgs::Any::STRING);
+      result.set_string_value(_s);
+      return result;
+    }
+
+    /////////////////////////////////////////////////
+    msgs::Any ConvertAny(const char *_s)
+    {
+      msgs::Any result;
+      result.set_type(msgs::Any::STRING);
+      result.set_string_value(std::string(_s));
+      return result;
+    }
+
+    /////////////////////////////////////////////////
+    msgs::Any ConvertAny(const bool _b)
+    {
+      msgs::Any result;
+      result.set_type(msgs::Any::BOOLEAN);
+      result.set_bool_value(_b);
+      return result;
+    }
+
+    /////////////////////////////////////////////////
+    msgs::Any ConvertAny(const ignition::math::Vector3d &_v)
+    {
+      msgs::Any result;
+      result.set_type(msgs::Any::VECTOR3D);
+      result.mutable_vector3d_value()->CopyFrom(Convert(_v));
+      return result;
+    }
+
+    /////////////////////////////////////////////////
+    msgs::Any ConvertAny(const common::Color &_c)
+    {
+      msgs::Any result;
+      result.set_type(msgs::Any::COLOR);
+      result.mutable_color_value()->CopyFrom(Convert(_c));
+      return result;
+    }
+
+    /////////////////////////////////////////////////
+    msgs::Any ConvertAny(const ignition::math::Pose3d &_p)
+    {
+      msgs::Any result;
+      result.set_type(msgs::Any::POSE3D);
+      result.mutable_pose3d_value()->CopyFrom(Convert(_p));
+      return result;
+    }
+
+    /////////////////////////////////////////////////
+    msgs::Any ConvertAny(const ignition::math::Quaterniond &_q)
+    {
+      msgs::Any result;
+      result.set_type(msgs::Any::QUATERNIOND);
+      result.mutable_quaternion_value()->CopyFrom(Convert(_q));
+      return result;
+    }
+
+    /////////////////////////////////////////////////
+    msgs::Any ConvertAny(const common::Time &_t)
+    {
+      msgs::Any result;
+      result.set_type(msgs::Any::TIME);
+      result.mutable_time_value()->CopyFrom(Convert(_t));
+      return result;
+    }
+
     /////////////////////////////////////////////////
     msgs::Vector3d Convert(const ignition::math::Vector3d &_v)
     {
@@ -293,6 +402,22 @@ namespace gazebo
       return result;
     }
 
+    /////////////////////////////////////////////
+    msgs::Inertial Convert(const ignition::math::Inertiald &_i)
+    {
+      msgs::Inertial result;
+      msgs::Set(&result, _i);
+      return result;
+    }
+
+    /////////////////////////////////////////////
+    msgs::Inertial Convert(const ignition::math::MassMatrix3d &_m)
+    {
+      msgs::Inertial result;
+      msgs::Set(&result, _m);
+      return result;
+    }
+
     /////////////////////////////////////////////
     msgs::PlaneGeom Convert(const ignition::math::Planed &_p)
     {
@@ -532,6 +657,18 @@ namespace gazebo
                                     ConvertIgn(_p.orientation()));
     }
 
+    /////////////////////////////////////////////
+    ignition::math::Inertiald Convert(const msgs::Inertial &_i)
+    {
+      auto pose = msgs::ConvertIgn(_i.pose());
+      return ignition::math::Inertiald(
+        ignition::math::MassMatrix3d(
+          _i.mass(),
+          ignition::math::Vector3d(_i.ixx(), _i.iyy(), _i.izz()),
+          ignition::math::Vector3d(_i.ixy(), _i.ixz(), _i.iyz())),
+        pose);
+    }
+
     /////////////////////////////////////////////
     common::Color Convert(const msgs::Color &_c)
     {
@@ -816,11 +953,25 @@ namespace gazebo
       else if (geomElem->GetName() == "heightmap")
       {
         result.set_type(msgs::Geometry::HEIGHTMAP);
-        msgs::Set(result.mutable_heightmap()->mutable_size(),
-            geomElem->Get<ignition::math::Vector3d>("size"));
+
+        // We do not want to set the size field to be the default values of
+        // [1, 1, 1] if not specified (size is optional for DEMs). So mark it as
+        // zero for now.
+        // TODO remove the required rule in heightmapgeom.proto's size field
+        ignition::math::Vector3d size;
+        if (geomElem->HasElement("size"))
+          size =  geomElem->Get<ignition::math::Vector3d>("size");
+        msgs::Set(result.mutable_heightmap()->mutable_size(), size);
+
         msgs::Set(result.mutable_heightmap()->mutable_origin(),
             geomElem->Get<ignition::math::Vector3d>("pos"));
 
+        if (geomElem->HasElement("sampling"))
+        {
+          result.mutable_heightmap()->set_sampling(
+              geomElem->Get<unsigned int>("sampling"));
+        }
+
         sdf::ElementPtr textureElem = geomElem->GetElement("texture");
         while (textureElem)
         {
@@ -847,6 +998,8 @@ namespace gazebo
         bool useTerrainPaging =
             geomElem->Get<bool>("use_terrain_paging");
         result.mutable_heightmap()->set_use_terrain_paging(useTerrainPaging);
+        result.mutable_heightmap()->set_filename(
+            geomElem->Get<std::string>("uri"));
       }
       else if (geomElem->GetName() == "mesh")
       {
@@ -967,21 +1120,20 @@ namespace gazebo
       // Set plugins of the visual
       if (_sdf->HasElement("plugin"))
       {
-        sdf::ElementPtr elem = _sdf->GetElement("plugin");
-        msgs::Plugin *plgnMsg = result.mutable_plugin();
-        // if (elem->HasElement("name"))
-          plgnMsg->set_name(elem->Get<std::string>("name"));
-        // if (elem->HasElement("filename"))
-          plgnMsg->set_filename(elem->Get<std::string>("filename"));
-
-        std::stringstream ss;
-        for (sdf::ElementPtr innerElem = elem->GetFirstElement();
-            innerElem;
-            innerElem = innerElem->GetNextElement(""))
+        sdf::ElementPtr pluginElem = _sdf->GetElement("plugin");
+        while (pluginElem)
         {
-          ss << innerElem->ToString("");
+          msgs::Plugin *pluginMsg = result.add_plugin();
+          pluginMsg->CopyFrom(PluginFromSDF(pluginElem));
+
+          // DEPRECATED in Gazebo7, remove in Gazebo8
+          // duplicate innerxml contents into an <sdf> tag to keep backwards
+          // compatibility
+          pluginMsg->set_innerxml(pluginMsg->innerxml() +
+              "\n<sdf>" + pluginMsg->innerxml() + "</sdf>");
+
+          pluginElem = pluginElem->GetNextElement("plugin");
         }
-        plgnMsg->set_innerxml("<sdf>" + ss.str() + "</sdf>");
       }
 
       return result;
@@ -1389,10 +1541,10 @@ namespace gazebo
       }
 
       // Set plugins of the visual
-      if (_msg.has_plugin())
+      for (int i = 0; i < _msg.plugin_size(); ++i)
       {
-        sdf::ElementPtr pluginElem = visualSDF->GetElement("plugin");
-        pluginElem = PluginToSDF(_msg.plugin(), pluginElem);
+        sdf::ElementPtr pluginElem = visualSDF->AddElement("plugin");
+        pluginElem = PluginToSDF(_msg.plugin(i), pluginElem);
       }
 
       return visualSDF;
@@ -2272,6 +2424,14 @@ namespace gazebo
         {
           geom->GetElement("pos")->Set(ConvertIgn(heightmapGeom.origin()));
         }
+        if (heightmapGeom.has_sampling())
+        {
+          // check if old version of sdformat is in use
+          if (geom->HasElementDescription("sampling"))
+          {
+            geom->GetElement("sampling")->Set(heightmapGeom.sampling());
+          }
+        }
         if (heightmapGeom.has_use_terrain_paging())
         {
           geom->GetElement("use_terrain_paging")->Set(
