@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2015 Open Source Robotics Foundation
+ * Copyright (C) 2012-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -25,19 +25,12 @@
   #include <Winsock2.h>
 #endif
 
-#include <gazebo/gazebo_config.h>
-
-#ifdef HAVE_GDAL
-# pragma GCC diagnostic push
-# pragma GCC diagnostic ignored "-Wfloat-equal"
-# include <gdalwarper.h>
-# include <gdal_priv.h>
-# pragma GCC diagnostic pop
-#endif
-
 #include <algorithm>
 #include <cmath>
 #include <string>
+#include <ignition/math/Helpers.hh>
+#include <gazebo/gazebo_config.h>
+
 #include "gazebo/common/Assert.hh"
 #include "gazebo/common/Console.hh"
 #include "gazebo/common/Image.hh"
@@ -78,6 +71,7 @@ void HeightmapShape::OnRequest(ConstRequestPtr &_msg)
     response.set_response("success");
 
     this->FillMsg(msg);
+    this->FillHeights(msg);
 
     response.set_type(msg.GetTypeName());
     std::string *serializedData = response.mutable_serialized_data();
@@ -88,105 +82,72 @@ void HeightmapShape::OnRequest(ConstRequestPtr &_msg)
 }
 
 //////////////////////////////////////////////////
-int HeightmapShape::LoadImageAsTerrain(const std::string &_filename)
+int HeightmapShape::LoadTerrainFile(const std::string &_filename)
 {
-  if (this->img.Load(_filename) != 0)
+  this->heightmapData = common::HeightmapDataLoader::LoadTerrainFile(_filename);
+  if (!this->heightmapData)
   {
-    gzerr << "Unable to load an image as a terrain [" << _filename << "]\n";
+    gzerr << "Unable to load heightmap data" << std::endl;
     return -1;
   }
 
-  this->heightmapData = static_cast<common::HeightmapData*>(&this->img);
-  this->heightmapSize = this->sdf->Get<math::Vector3>("size");
-
-  return 0;
-}
-
 #ifdef HAVE_GDAL
-//////////////////////////////////////////////////
-int HeightmapShape::LoadDEMAsTerrain(const std::string &_filename)
-{
-  if (this->dem.Load(_filename) != 0)
+  // DEM
+  auto demData = dynamic_cast<common::Dem *>(this->heightmapData);
+  if (demData)
   {
-    gzerr << "Unable to load a DEM file as a terrain [" << _filename << "]\n";
-    return -1;
-  }
+    this->dem = *demData;
+    if (this->sdf->HasElement("size"))
+    {
+      this->heightmapSize = this->sdf->Get<math::Vector3>("size");
+    }
+    else
+    {
+      this->heightmapSize.x = this->dem.GetWorldWidth();
+      this->heightmapSize.y = this->dem.GetWorldHeight();
+      this->heightmapSize.z = this->dem.GetMaxElevation() -
+          this->dem.GetMinElevation();
+    }
 
-  if (this->sdf->HasElement("size"))
-  {
-    this->heightmapSize = this->sdf->Get<math::Vector3>("size");
+    // Modify the reference geotedic latitude/longitude.
+    // A GPS sensor will use the real georeferenced coordinates of the terrain.
+    common::SphericalCoordinatesPtr sphericalCoordinates;
+    sphericalCoordinates = this->world->GetSphericalCoordinates();
+
+    if (sphericalCoordinates)
+    {
+      ignition::math::Angle latitude, longitude;
+      double elevation;
+
+      this->dem.GetGeoReferenceOrigin(latitude, longitude);
+      elevation = this->dem.GetElevation(0.0, 0.0);
+
+      sphericalCoordinates->SetLatitudeReference(latitude);
+      sphericalCoordinates->SetLongitudeReference(longitude);
+      sphericalCoordinates->SetElevationReference(elevation);
+      sphericalCoordinates.reset();
+    }
+    else
+      gzerr << "Unable to get a valid SphericalCoordinates pointer\n";
+
+    return 0;
   }
+  // Image
   else
-  {
-    this->heightmapSize.x = this->dem.GetWorldWidth();
-    this->heightmapSize.y = this->dem.GetWorldHeight();
-    this->heightmapSize.z = this->dem.GetMaxElevation() -
-        std::max(0.0f, this->dem.GetMinElevation());
-  }
-
-  this->heightmapData = static_cast<common::HeightmapData*>(&this->dem);
-
-  // Modify the reference geotedic latitude/longitude.
-  // A GPS sensor will use the real georeferenced coordinates of the terrain.
-  common::SphericalCoordinatesPtr sphericalCoordinates;
-  sphericalCoordinates = this->world->GetSphericalCoordinates();
-
-  if (sphericalCoordinates)
-  {
-    ignition::math::Angle latitude, longitude;
-    double elevation;
-
-    this->dem.GetGeoReferenceOrigin(latitude, longitude);
-    elevation = this->dem.GetElevation(0.0, 0.0);
-
-    sphericalCoordinates->SetLatitudeReference(latitude);
-    sphericalCoordinates->SetLongitudeReference(longitude);
-    sphericalCoordinates->SetElevationReference(elevation);
-    sphericalCoordinates.reset();
-  }
-  else
-    gzerr << "Unable to get a valid SphericalCoordinates pointer\n";
-
-  return 0;
-}
-
-//////////////////////////////////////////////////
-int HeightmapShape::LoadTerrainFile(const std::string &_filename)
-{
-  // Register the GDAL drivers
-  GDALAllRegister();
-
-  GDALDataset *poDataset = reinterpret_cast<GDALDataset *>
-      (GDALOpen(_filename.c_str(), GA_ReadOnly));
-
-  if (!poDataset)
-  {
-    gzerr << "Unrecognized terrain format in file [" << _filename << "]\n";
-    return -1;
-  }
-
-  this->fileFormat = poDataset->GetDriver()->GetDescription();
-  GDALClose(reinterpret_cast<GDALDataset *>(poDataset));
-
-  // Check if the heightmap file is an image
-  if (fileFormat == "JPEG" || fileFormat == "PNG")
-  {
-    // Load the terrain file as an image
-    return this->LoadImageAsTerrain(_filename);
-  }
-  else
-  {
-    // Load the terrain file as a DEM
-    return this->LoadDEMAsTerrain(_filename);
-  }
-}
-#else
-int HeightmapShape::LoadTerrainFile(const std::string &_filename)
-{
-  // Load the terrain file as an image
-  return this->LoadImageAsTerrain(_filename);
-}
 #endif
+  {
+    auto imageData =
+        dynamic_cast<common::ImageHeightmap *>(this->heightmapData);
+    if (imageData)
+    {
+      this->img = *imageData;
+      this->heightmapSize = this->sdf->Get<math::Vector3>("size");
+      return 0;
+    }
+  }
+
+  return -1;
+}
 
 //////////////////////////////////////////////////
 void HeightmapShape::Load(sdf::ElementPtr _sdf)
@@ -201,15 +162,31 @@ void HeightmapShape::Load(sdf::ElementPtr _sdf)
     return;
   }
 
-  if (LoadTerrainFile(filename) != 0)
+  if (this->LoadTerrainFile(filename) != 0)
   {
     gzerr << "Heightmap data size must be square, with a size of 2^n+1\n";
     return;
   }
 
+  this->subSampling = 2u;
+  if (this->sdf->HasElement("sampling"))
+  {
+    unsigned int s = this->sdf->Get<unsigned int>("sampling");
+    if (s == 0u || s & (s - 1u))
+    {
+      gzerr << "Heightmap sampling value must be a power of 2. "
+            << "The default value of 2 will be used instead." << std::endl;
+      this->subSampling = 2;
+    }
+    else
+    {
+      this->subSampling = static_cast<int>(s);
+    }
+  }
+
   // Check if the geometry of the terrain data matches Ogre constrains
   if (this->heightmapData->GetWidth() != this->heightmapData->GetHeight() ||
-      !math::isPowerOfTwo(this->heightmapData->GetWidth() - 1))
+      !ignition::math::isPowerOfTwo(this->heightmapData->GetWidth() - 1))
   {
     gzerr << "Heightmap data size must be square, with a size of 2^n+1\n";
     return;
@@ -232,20 +209,28 @@ void HeightmapShape::Init()
       &HeightmapShape::OnRequest, this, true);
   this->responsePub = this->node->Advertise<msgs::Response>("~/response");
 
-  this->subSampling = 2;
-
   math::Vector3 terrainSize = this->GetSize();
 
   // sampling size along image width and height
-  this->vertSize = (this->heightmapData->GetWidth() * this->subSampling)-1;
+  this->vertSize = (this->heightmapData->GetWidth() * this->subSampling)
+      - this->subSampling + 1;
   this->scale.x = terrainSize.x / this->vertSize;
   this->scale.y = terrainSize.y / this->vertSize;
 
-  if (math::equal(this->heightmapData->GetMaxElevation(), 0.0f))
-    this->scale.z = fabs(terrainSize.z);
+  // TODO add a virtual HeightmapData::GetMinElevation function to avoid the
+  // ifdef check. i.e. heightmapSizeZ = GetMaxElevation - GetMinElevation
+  double heightmapSizeZ = this->heightmapData->GetMaxElevation();
+#ifdef HAVE_GDAL
+  // DEM
+  auto demData = dynamic_cast<common::Dem *>(this->heightmapData);
+  if (demData)
+    heightmapSizeZ = heightmapSizeZ - demData->GetMinElevation();
+#endif
+
+  if (ignition::math::equal(heightmapSizeZ, 0.0))
+    this->scale.z = 1.0;
   else
-    this->scale.z = fabs(terrainSize.z) /
-                    this->heightmapData->GetMaxElevation();
+    this->scale.z = fabs(terrainSize.z) / heightmapSizeZ;
 
   // Step 1: Construct the heightmap lookup table
   this->heightmapData->FillHeightMap(this->subSampling, this->vertSize,
@@ -287,6 +272,16 @@ void HeightmapShape::FillMsg(msgs::Geometry &_msg)
   _msg.mutable_heightmap()->set_width(this->vertSize);
   _msg.mutable_heightmap()->set_height(this->vertSize);
 
+  msgs::Set(_msg.mutable_heightmap()->mutable_size(), this->GetSize().Ign());
+  msgs::Set(_msg.mutable_heightmap()->mutable_origin(), this->GetPos().Ign());
+  _msg.mutable_heightmap()->set_filename(this->GetURI());
+  _msg.mutable_heightmap()->set_sampling(
+      static_cast<unsigned int>(this->subSampling));
+}
+
+//////////////////////////////////////////////////
+void HeightmapShape::FillHeights(msgs::Geometry &_msg) const
+{
   for (unsigned int y = 0; y < this->vertSize; ++y)
   {
     for (unsigned int x = 0; x < this->vertSize; ++x)
@@ -295,10 +290,6 @@ void HeightmapShape::FillMsg(msgs::Geometry &_msg)
       _msg.mutable_heightmap()->add_heights(this->heights[index]);
     }
   }
-
-  msgs::Set(_msg.mutable_heightmap()->mutable_size(), this->GetSize().Ign());
-  msgs::Set(_msg.mutable_heightmap()->mutable_origin(), this->GetPos().Ign());
-  _msg.mutable_heightmap()->set_filename(this->img.GetFilename());
 }
 
 //////////////////////////////////////////////////
@@ -316,10 +307,11 @@ math::Vector2i HeightmapShape::GetVertexCount() const
 /////////////////////////////////////////////////
 float HeightmapShape::GetHeight(int _x, int _y) const
 {
-  if (_x < 0 || _y < 0)
+  int index =  _y * this->vertSize + _x;
+  if (_x < 0 || _y < 0 || index >= static_cast<int>(this->heights.size()))
     return 0.0;
 
-  return this->heights[_y * this->vertSize + _x];
+  return this->heights[index];
 }
 
 /////////////////////////////////////////////////
