@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2015 Open Source Robotics Foundation
+ * Copyright (C) 2012-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -41,6 +41,17 @@ Road::Road(BasePtr _parent)
 /////////////////////////////////////////////////
 Road::~Road()
 {
+  this->Fini();
+}
+
+/////////////////////////////////////////////////
+void Road::Fini()
+{
+  this->roadPub.reset();
+
+  if (this->node)
+    this->node->Fini();
+  this->node.reset();
 }
 
 /////////////////////////////////////////////////
