@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2015 Open Source Robotics Foundation
+ * Copyright (C) 2012-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -71,7 +71,8 @@ void ODEHeightmapShape::Init()
       0);  // wrap mode
 
   // Step 4: Restrict the bounds of the AABB to improve efficiency
-  dGeomHeightfieldDataSetBounds(this->odeData, 0, this->GetSize().z);
+  dGeomHeightfieldDataSetBounds(this->odeData, this->GetMinHeight(),
+      this->GetMaxHeight());
 
   oParent->SetCollision(dCreateHeightfield(0, this->odeData, 1), false);
   oParent->SetStatic(true);
