@@ -129,6 +129,11 @@ class Colliders_TBB
   private: dContactGeom* contactCollisions;
 };
 
+//////////////////////////////////////////////////
+extern "C" void dMessageQuiet(int, const char *, va_list)
+{
+}
+
 //////////////////////////////////////////////////
 ODEPhysics::ODEPhysics(WorldPtr _world)
     : PhysicsEngine(_world), dataPtr(new ODEPhysicsPrivate)
@@ -1507,6 +1512,18 @@ bool ODEPhysics::SetParam(const std::string &_key, const boost::any &_value)
       dWorldSetQuickStepExtraFrictionIterations(this->dataPtr->worldId,
         boost::any_cast<int>(_value));
     }
+    else if (_key == "ode_quiet")
+    {
+      bool odeQuiet = boost::any_cast<bool>(_value);
+      if (odeQuiet)
+      {
+        dSetMessageHandler(&dMessageQuiet);
+      }
+      else
+      {
+        dSetMessageHandler(0);
+      }
+    }
     else
     {
       return PhysicsEngine::SetParam(_key, _value);
@@ -1594,6 +1611,8 @@ bool ODEPhysics::GetParam(const std::string &_key, boost::any &_value) const
     _value = dWorldGetQuickStepExtraFrictionIterations(this->dataPtr->worldId);
   else if (_key == "friction_model")
     _value = this->GetFrictionModel();
+  else if (_key == "ode_quiet")
+    _value = dGetMessageHandler() != 0;
   else if (_key == "world_step_solver")
     _value = this->GetWorldStepSolverType();
   else
