@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2015 Open Source Robotics Foundation
+ * Copyright (C) 2012-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -29,7 +29,7 @@ ODESurfaceParams::ODESurfaceParams()
     kp(1000000000000), kd(1), cfm(0), erp(0.2),
     maxVel(0.01), minDepth(0),
     slip1(0), slip2(0),
-    frictionPyramid(new FrictionPyramid())
+    frictionPyramid(new physics::FrictionPyramid())
 {
 }
 
@@ -79,6 +79,23 @@ void ODESurfaceParams::Load(sdf::ElementPtr _sdf)
         gzerr << "Surface friction sdf member is NULL" << std::endl;
       else
       {
+        sdf::ElementPtr torsionalElem = frictionElem->GetElement("torsional");
+        if (torsionalElem)
+        {
+          this->frictionPyramid->SetMuTorsion(
+            torsionalElem->Get<double>("coefficient"));
+          this->frictionPyramid->SetPatchRadius(
+            torsionalElem->Get<double>("patch_radius"));
+          this->frictionPyramid->SetSurfaceRadius(
+            torsionalElem->Get<double>("surface_radius"));
+          this->frictionPyramid->SetUsePatchRadius(
+            torsionalElem->Get<bool>("use_patch_radius"));
+
+          sdf::ElementPtr torsionalOdeElem = torsionalElem->GetElement("ode");
+          if (torsionalOdeElem)
+            this->slipTorsion = torsionalOdeElem->Get<double>("slip");
+        }
+
         sdf::ElementPtr frictionOdeElem = frictionElem->GetElement("ode");
         if (!frictionOdeElem)
           gzerr << "Surface friction ode sdf member is NULL" << std::endl;
@@ -114,6 +131,13 @@ void ODESurfaceParams::Load(sdf::ElementPtr _sdf)
           this->maxVel = contactOdeElem->Get<double>("max_vel");
           this->minDepth = contactOdeElem->Get<double>("min_depth");
         }
+        this->frictionPyramid->SetPoissonsRatio(
+          contactElem->Get<double>("poissons_ratio"));
+        this->frictionPyramid->SetElasticModulus(
+          contactElem->Get<double>("elastic_modulus"));
+        // gzerr << "poisson: [" << this->frictionPyramid->PoissonsRatio()
+        //       << "] em: [" << this->frictionPyramid->ElasticModulus()
+        //       << "] \n";
       }
     }
   }
@@ -124,18 +148,31 @@ void ODESurfaceParams::FillMsg(msgs::Surface &_msg)
 {
   SurfaceParams::FillMsg(_msg);
 
-  _msg.mutable_friction()->set_mu(this->frictionPyramid->GetMuPrimary());
-  _msg.mutable_friction()->set_mu2(this->frictionPyramid->GetMuSecondary());
+  _msg.mutable_friction()->set_mu(this->frictionPyramid->MuPrimary());
+  _msg.mutable_friction()->set_mu2(this->frictionPyramid->MuSecondary());
   _msg.mutable_friction()->set_slip1(this->slip1);
   _msg.mutable_friction()->set_slip2(this->slip2);
   msgs::Set(_msg.mutable_friction()->mutable_fdir1(),
             this->frictionPyramid->direction1.Ign());
 
+  _msg.mutable_friction()->mutable_torsional()->set_coefficient(
+      this->frictionPyramid->MuTorsion());
+
+  _msg.mutable_friction()->mutable_torsional()->set_patch_radius(
+      this->frictionPyramid->PatchRadius());
+  _msg.mutable_friction()->mutable_torsional()->set_surface_radius(
+      this->frictionPyramid->SurfaceRadius());
+  _msg.mutable_friction()->mutable_torsional()->set_use_patch_radius(
+      this->frictionPyramid->UsePatchRadius());
+  _msg.mutable_friction()->mutable_torsional()->mutable_ode()->set_slip(
+      this->slipTorsion);
+
   _msg.set_restitution_coefficient(this->bounce);
   _msg.set_bounce_threshold(this->bounceThreshold);
 
   _msg.set_soft_cfm(this->cfm);
   _msg.set_soft_erp(this->erp);
+  _msg.set_elastic_modulus(this->frictionPyramid->ElasticModulus());
   _msg.set_kp(this->kp);
   _msg.set_kd(this->kd);
   _msg.set_max_vel(this->maxVel);
@@ -158,8 +195,39 @@ void ODESurfaceParams::ProcessMsg(const msgs::Surface &_msg)
     if (_msg.friction().has_slip2())
       this->slip2 = _msg.friction().slip2();
     if (_msg.friction().has_fdir1())
+    {
       this->frictionPyramid->direction1 =
         msgs::ConvertIgn(_msg.friction().fdir1());
+    }
+
+    if (_msg.friction().has_torsional())
+    {
+      if (_msg.friction().torsional().has_coefficient())
+      {
+        this->frictionPyramid->SetMuTorsion(
+            _msg.friction().torsional().coefficient());
+      }
+      if (_msg.friction().torsional().has_patch_radius())
+      {
+        this->frictionPyramid->SetPatchRadius(
+            _msg.friction().torsional().patch_radius());
+      }
+      if (_msg.friction().torsional().has_surface_radius())
+      {
+        this->frictionPyramid->SetSurfaceRadius(
+            _msg.friction().torsional().surface_radius());
+      }
+      if (_msg.friction().torsional().has_use_patch_radius())
+      {
+        this->frictionPyramid->SetUsePatchRadius(
+            _msg.friction().torsional().use_patch_radius());
+      }
+      if (_msg.friction().torsional().has_ode())
+      {
+        if (_msg.friction().torsional().ode().has_slip())
+          this->slipTorsion = _msg.friction().torsional().ode().slip();
+      }
+    }
   }
 
   if (_msg.has_restitution_coefficient())
@@ -170,6 +238,8 @@ void ODESurfaceParams::ProcessMsg(const msgs::Surface &_msg)
     this->cfm = _msg.soft_cfm();
   if (_msg.has_soft_erp())
     this->erp = _msg.soft_erp();
+  if (_msg.has_elastic_modulus())
+    this->frictionPyramid->SetElasticModulus(_msg.elastic_modulus());
   if (_msg.has_kp())
     this->kp = _msg.kp();
   if (_msg.has_kd())
@@ -185,3 +255,9 @@ FrictionPyramidPtr ODESurfaceParams::GetFrictionPyramid() const
 {
   return this->frictionPyramid;
 }
+
+/////////////////////////////////////////////////
+FrictionPyramidPtr ODESurfaceParams::FrictionPyramid() const
+{
+  return this->frictionPyramid;
+}
