@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2015 Open Source Robotics Foundation
+ * Copyright (C) 2012-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,8 +19,11 @@
 #include <boost/assign/list_of.hpp>
 #include "gazebo/test/ServerFixture.hh"
 
+#include "test_config.h"
+
+
 using namespace gazebo;
-class Heightmap_TEST : public ServerFixture
+class Heightmap_TEST : public RenderingFixture
 {
 };
 
@@ -31,18 +34,18 @@ TEST_F(Heightmap_TEST, splitTerrain)
   Load("worlds/empty.world");
 
   gazebo::rendering::ScenePtr scene = gazebo::rendering::get_scene("default");
-  ASSERT_TRUE(scene != NULL);
+  ASSERT_TRUE(scene != nullptr);
 
   scene = gazebo::rendering::create_scene("default", false);
 
   // Make sure that the scene is created
-  ASSERT_TRUE(scene != NULL);
+  ASSERT_TRUE(scene != nullptr);
 
   gazebo::rendering::Heightmap *heightmap =
       new gazebo::rendering::Heightmap(scene);
 
   // Check that the heightmap is created
-  EXPECT_TRUE(heightmap != NULL);
+  EXPECT_TRUE(heightmap != nullptr);
 
   std::vector<float> heights;
   std::vector<std::vector<float> > heightsSplit;
@@ -56,10 +59,10 @@ TEST_F(Heightmap_TEST, splitTerrain)
     heights[i] = i + 1;
   }
 
-  heightmap->SplitHeights(heights, heightmap->GetTerrainSubdivisionCount(),
+  heightmap->SplitHeights(heights, heightmap->TerrainSubdivisionCount(),
       heightsSplit);
 
-  ASSERT_TRUE(heightsSplit.size() == heightmap->GetTerrainSubdivisionCount());
+  ASSERT_TRUE(heightsSplit.size() == heightmap->TerrainSubdivisionCount());
 
   // Precomputed subterrains for a known 9 x 9 terrain starting from 1 and with
   // consecutive values
@@ -82,13 +85,65 @@ TEST_F(Heightmap_TEST, splitTerrain)
   slices[15] = {61, 62, 62, 70, 71, 71, 70, 71, 71};
 
   // Make sure that the subterrain heights matches the precomputed slices
-  for (unsigned int i = 0; i < heightmap->GetTerrainSubdivisionCount(); ++i)
+  for (unsigned int i = 0; i < heightmap->TerrainSubdivisionCount(); ++i)
   {
     EXPECT_TRUE(std::equal(heightsSplit[i].begin(), heightsSplit[i].end(),
           slices[i].begin()));
   }
 }
 
+#ifdef HAVE_GDAL
+/////////////////////////////////////////////////
+/// \brief Test Loading a terrain from a DEM file
+TEST_F(Heightmap_TEST, LoadDEM)
+{
+  Load("worlds/empty.world");
+
+  gazebo::rendering::ScenePtr scene = gazebo::rendering::get_scene("default");
+  ASSERT_TRUE(scene != nullptr);
+
+  gazebo::rendering::Heightmap *heightmap =
+      new gazebo::rendering::Heightmap(scene);
+
+  // Check that the heightmap is created
+  EXPECT_TRUE(heightmap != nullptr);
+
+  // create a heightmapgeom msg for the heightmap
+  msgs::Visual msg;
+  msg.set_name("heightmap_visual");
+  msg.set_parent_name("heightmap_visual_parent");
+  auto geomMsg = msg.mutable_geometry();
+  // set size to zero to let heightmap read actual size from dem file
+  msgs::Set(geomMsg->mutable_heightmap()->mutable_size(),
+      ignition::math::Vector3d::Zero);
+
+  boost::filesystem::path path = TEST_PATH;
+  path /= "data/dem_squared.tif";
+  geomMsg->mutable_heightmap()->set_filename(path.string());
+
+  // load the heightmap
+  auto visMsg = new ConstVisualPtr(&msg);
+  heightmap->LoadFromMsg(*visMsg);
+
+  // verify heightmap image size
+  unsigned int subsampling = 2;
+  unsigned int tifSize = 129;
+  unsigned int vertSize = (tifSize * subsampling) - 1;
+  common::Image img = heightmap->Image();
+  EXPECT_EQ(img.GetWidth(), vertSize);
+  EXPECT_EQ(img.GetHeight(), vertSize);
+
+  // verify heights between value obtained using ray casting (heightmap->Height)
+  // and the actual elevation data (dem.GetElevation)
+  common::Dem dem;
+  EXPECT_EQ(dem.Load(path.string()), 0);
+  EXPECT_DOUBLE_EQ(heightmap->Height(0, 0),
+      dem.GetElevation(dem.GetWidth()/2, dem.GetHeight()/2));
+
+  delete heightmap;
+}
+#endif
+
 /////////////////////////////////////////////////
 int main(int argc, char **argv)
 {
