@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2015 Open Source Robotics Foundation
+ * Copyright (C) 2014-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -71,7 +71,7 @@ void JointVisual::Load(ConstJointPtr &_msg)
     // create extra joint visual for axis1
     VisualPtr parentVis;
     if (_msg->has_parent() && _msg->parent() == "world")
-      parentVis = this->GetScene()->GetWorldVisual();
+      parentVis = this->GetScene()->WorldVisual();
     else if (_msg->has_parent_id())
       parentVis = this->GetScene()->GetVisual(_msg->parent_id());
 
@@ -169,13 +169,16 @@ void JointVisual::UpdateAxis(ArrowVisualPtr _arrowVisual,
 
   if (_useParentFrame)
   {
-    // if set to use parent model frame
-    // rotate the arrow visual relative to the model
-    VisualPtr model = this->GetRootVisual();
-    math::Quaternion quatFromModel =
-        model->GetWorldPose().rot.GetInverse()*this->GetWorldPose().rot;
-    _arrowVisual->SetRotation(quatFromModel.GetInverse() *
-        _arrowVisual->GetRotation());
+    VisualPtr linkVis = this->GetParent();
+    ignition::math::Pose3d linkInitPose = linkVis->InitialRelativePose();
+
+    // get rotation of joint visual in model frame
+    ignition::math::Quaterniond quatFromModel =
+        (this->GetPose().Ign() + linkInitPose).Rot();
+
+    // rotate arrow visual so that the axis vector applies to the model frame.
+    _arrowVisual->SetRotation(quatFromModel.Inverse() *
+        _arrowVisual->GetRotation().Ign());
   }
   _arrowVisual->ShowRotation(_type == msgs::Joint::REVOLUTE ||
                              _type == msgs::Joint::REVOLUTE2 ||
@@ -268,7 +271,7 @@ void JointVisual::UpdateFromMsg(ConstJointPtr &_msg)
     {
       VisualPtr parentVis;
       if (_msg->has_parent() && _msg->parent() == "world")
-        parentVis = this->GetScene()->GetWorldVisual();
+        parentVis = this->GetScene()->WorldVisual();
       else if (_msg->has_parent_id())
         parentVis = this->GetScene()->GetVisual(_msg->parent_id());
 
