@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2015 Open Source Robotics Foundation
+ * Copyright (C) 2012-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,6 +17,7 @@
 #include "gazebo/common/Color.hh"
 #include "gazebo/rendering/ogre_gazebo.h"
 #include "gazebo/common/Console.hh"
+#include "gazebo/rendering/RenderEngine.hh"
 #include "gazebo/rendering/Conversions.hh"
 #include "gazebo/rendering/Material.hh"
 
@@ -178,6 +179,8 @@ void Material::Update(const gazebo::common::Material *_mat)
   if (!_mat->GetTextureImage().empty() &&
       pass->getTextureUnitState(_mat->GetTextureImage()) == NULL)
   {
+    // Make sure to add the path to the texture image.
+    RenderEngine::Instance()->AddResourcePath(_mat->GetTextureImage());
     Ogre::TextureUnitState *texState = pass->createTextureUnitState(
         _mat->GetTextureImage());
     texState->setTextureName(_mat->GetTextureImage());
