@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2015 Open Source Robotics Foundation
+ * Copyright (C) 2012-2016 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,6 +15,7 @@
  *
 */
 
+#include <cmath>
 #include "gazebo/test/ServerFixture.hh"
 #include "gazebo/physics/physics.hh"
 #include "gazebo/sensors/sensors.hh"
@@ -28,6 +29,9 @@ using namespace gazebo;
 class ContactSensor : public ServerFixture,
                       public testing::WithParamInterface<const char*>
 {
+  /// \brief Test removing a model that has a contact sensor
+  public: void ModelRemoval(const std::string &_physicsEngine);
+
   /// \brief Test moving a model while in contact.
   /// \param[in] _physicsEngine Physics engine to use.
   public: void MoveTool(const std::string &_physicsEngine);
@@ -50,6 +54,130 @@ void ContactSensor::Callback(const ConstContactsPtr &/*_msg*/)
   g_messageCount++;
 }
 
+
+////////////////////////////////////////////////////////////////////////
+void ContactSensor::ModelRemoval(const std::string &_physicsEngine)
+{
+  // Load an empty world
+  Load("worlds/empty.world", true, _physicsEngine);
+  physics::WorldPtr world = physics::get_world("default");
+  ASSERT_TRUE(world != nullptr);
+
+  // Verify physics engine type
+  physics::PhysicsEnginePtr physics = world->GetPhysicsEngine();
+  ASSERT_TRUE(physics != nullptr);
+  EXPECT_EQ(physics->GetType(), _physicsEngine);
+
+  // check initial topics count
+  auto topics = transport::getAdvertisedTopics();
+  int topicsCount = 0;
+  for (auto iter : topics)
+  {
+    for (auto str : iter.second)
+    {
+      topicsCount++;
+    }
+  }
+  EXPECT_GT(topicsCount, 0);
+
+  // spanw the model
+  std::string modelName = "contactModel";
+  std::string contactSensorName = "contactSensor";
+  ignition::math::Pose3d modelPose(0, -0.3, 1.5, M_PI/2.0, 0, 0);
+
+  SpawnUnitContactSensor(modelName, contactSensorName,
+      "cylinder", modelPose.Pos(), modelPose.Rot().Euler());
+
+  sensors::SensorPtr sensor = sensors::get_sensor(contactSensorName);
+  sensors::ContactSensorPtr contactSensor =
+      std::dynamic_pointer_cast<sensors::ContactSensor>(sensor);
+
+  ASSERT_TRUE(contactSensor != nullptr);
+
+  sensors::SensorManager::Instance()->Init();
+  sensors::SensorManager::Instance()->RunThreads();
+
+  EXPECT_FALSE(contactSensor->IsActive());
+
+  unsigned int expectedColCount = 1;
+  EXPECT_EQ(contactSensor->GetCollisionCount(), expectedColCount);
+
+  contactSensor->SetActive(true);
+
+  EXPECT_TRUE(contactSensor->IsActive());
+
+  physics::ModelPtr contactModel = world->GetModel(modelName);
+  ASSERT_TRUE(contactModel != nullptr);
+
+  // check new topic are published
+  // there should be more than 1 new topic:
+  //   1 new factory topic and 2 new contact sensor topics
+  int wait = 0;
+  int maxWait = 20;
+  int topicsCountModel = 0;
+  int topicsCountModelName = 0;
+  while (topicsCountModel <= topicsCount+2 && wait < maxWait)
+  {
+    common::Time::MSleep(100);
+    topicsCountModel = 0;
+    auto modelTopics = transport::getAdvertisedTopics();
+    for (auto iter : modelTopics)
+    {
+      for (auto str : iter.second)
+      {
+        topicsCountModel++;
+        if (str.find(modelName) != std::string::npos)
+          topicsCountModelName++;
+      }
+    }
+    wait++;
+  }
+  EXPECT_GT(topicsCountModel, topicsCount+1);
+  EXPECT_GT(topicsCountModelName, 0);
+
+  // remove the model
+  world->RemoveModel(contactModel);
+
+  contactModel = world->GetModel(modelName);
+  EXPECT_TRUE(contactModel == nullptr);
+
+  int sleep = 0;
+  int maxSleep  = 20;
+  while (sensors::get_sensor(contactSensorName) && sleep < maxSleep)
+  {
+    common::Time::MSleep(30);
+    sleep++;
+  }
+  EXPECT_TRUE(sensors::get_sensor(contactSensorName) == nullptr);
+
+  // wait for topics cleanup
+  // verify there are no more contact sensor topics and the number of topics
+  // are back to the initial condition + 1 new factory topic.
+  auto topicsAfter = transport::getAdvertisedTopics();
+  int j = 0;
+  for (j = 0; j < 5 && topicsAfter.size() > (topics.size() + 1); ++j)
+  {
+    common::Time::MSleep(1000);
+    topicsAfter = transport::getAdvertisedTopics();
+  }
+  EXPECT_LT(j, 5);
+  int topicsCountAfter = 0;
+  for (auto iter : topicsAfter)
+  {
+    for (auto str : iter.second)
+    {
+      topicsCountAfter++;
+      EXPECT_TRUE(str.find(modelName) == std::string::npos);
+    }
+  }
+  EXPECT_EQ(topicsCountAfter, topicsCount+1);
+}
+
+TEST_P(ContactSensor, ModelRemoval)
+{
+  ModelRemoval(GetParam());
+}
+
 ////////////////////////////////////////////////////////////////////////
 // Test moving a model while in contact
 // addresses a failure in pull request #1610 for simbody
@@ -120,14 +248,14 @@ void ContactSensor::MultipleSensors(const std::string &_physicsEngine)
   {
     sensors::SensorPtr sensor1 = sensors::get_sensor(contactSensorName1);
     sensors::ContactSensorPtr contactSensor1 =
-        boost::dynamic_pointer_cast<sensors::ContactSensor>(sensor1);
+        std::dynamic_pointer_cast<sensors::ContactSensor>(sensor1);
     ASSERT_TRUE(contactSensor1 != NULL);
   }
 
   {
     sensors::SensorPtr sensor2 = sensors::get_sensor(contactSensorName2);
     sensors::ContactSensorPtr contactSensor2 =
-        boost::dynamic_pointer_cast<sensors::ContactSensor>(sensor2);
+        std::dynamic_pointer_cast<sensors::ContactSensor>(sensor2);
     ASSERT_TRUE(contactSensor2 != NULL);
   }
 
@@ -222,13 +350,13 @@ void ContactSensor::StackTest(const std::string &_physicsEngine)
 
   sensors::SensorPtr sensor01 = sensors::get_sensor(contactSensorName01);
   sensors::ContactSensorPtr contactSensor01 =
-      boost::dynamic_pointer_cast<sensors::ContactSensor>(sensor01);
+      std::dynamic_pointer_cast<sensors::ContactSensor>(sensor01);
 
   ASSERT_TRUE(contactSensor01 != NULL);
 
   sensors::SensorPtr sensor02 = sensors::get_sensor(contactSensorName02);
   sensors::ContactSensorPtr contactSensor02 =
-      boost::dynamic_pointer_cast<sensors::ContactSensor>(sensor02);
+      std::dynamic_pointer_cast<sensors::ContactSensor>(sensor02);
 
   ASSERT_TRUE(contactSensor02 != NULL);
 
@@ -272,8 +400,8 @@ void ContactSensor::StackTest(const std::string &_physicsEngine)
       && --steps > 0)
   {
     world->Step(1);
-    contacts01 = contactSensor01->GetContacts();
-    contacts02 = contactSensor02->GetContacts();
+    contacts01 = contactSensor01->Contacts();
+    contacts02 = contactSensor02->Contacts();
     // gzdbg << "steps[" << steps
     //       << "] contacts01[" << contacts01.contact_size()
     //       << "] contacts02[" << contacts02.contact_size()
@@ -342,7 +470,7 @@ void ContactSensor::StackTest(const std::string &_physicsEngine)
 
         EXPECT_NEAR(contacts[k].contact(i).normal(j).x(), 0, TOL);
         EXPECT_NEAR(contacts[k].contact(i).normal(j).y(), 0, TOL);
-        EXPECT_NEAR(contacts[k].contact(i).normal(j).z(), 1, TOL);
+        EXPECT_NEAR(std::abs(contacts[k].contact(i).normal(j).z()), 1, TOL);
 
         if (body1)
         {
@@ -446,7 +574,7 @@ void ContactSensor::TorqueTest(const std::string &_physicsEngine)
 
   sensors::SensorPtr sensor = sensors::get_sensor(contactSensorName);
   sensors::ContactSensorPtr contactSensor =
-      boost::dynamic_pointer_cast<sensors::ContactSensor>(sensor);
+      std::dynamic_pointer_cast<sensors::ContactSensor>(sensor);
 
   ASSERT_TRUE(contactSensor != NULL);
 
@@ -484,12 +612,12 @@ void ContactSensor::TorqueTest(const std::string &_physicsEngine)
   while (contacts.contact_size() == 0 && --steps > 0)
   {
     world->Step(1);
-    contacts = contactSensor->GetContacts();
+    contacts = contactSensor->Contacts();
   }
 
   EXPECT_GT(steps, 0);
 
-  contacts = contactSensor->GetContacts();
+  contacts = contactSensor->Contacts();
 
   unsigned int ColInd = 0;
   physics::CollisionPtr col = contactModel->GetLink()->GetCollision(ColInd);
